#!/usr/bin/env python
# sapdberr.py

import sys
import string

_errInfos = {
-31000: ('SQL', -31000, 'Gateway DB error:', '', ''),
-28999: ('liveCache', -28999, 'required DBPError', '', ''),
-28950: ('liveCache', -28950, 'System error : missing object flush during commit', '', ''),
-28903: ('liveCache', -28903, 'DBFunction $1 must return a value', '', ''),
-28902: ('liveCache', -28902, 'Too many nested try/catch statements', '', ''),
-28901: ('liveCache', -28901, 'No case match found', '', ''),
-28831: ('liveCache', -28831, 'Wrong page count (internal error)', '', ''),
-28822: ('liveCache', -28822, 'Invalid object file ID (internal error)', '', ''),
-28819: ('liveCache', -28819, 'Object has been updated by other transactions', [], []),
-28818: ('liveCache', -28818, 'Wrong object position', [], []),
-28817: ('liveCache', -28817, 'Wrong object length', [], []),
-28816: ('liveCache', -28816, 'Hash memory exceeded', '', ''),
-28815: ('liveCache', -28815, 'Object history not found', [], []),
-28814: ('liveCache', -28814, 'Object not found', [], []),
-28813: ('liveCache', -28813, 'Unknown consistent version', [], []),
-28812: ('liveCache', -28812, 'Invalid iterator', '', ''),
-28811: ('liveCache', -28811, 'Hash key not found', '', ''),
-28810: ('liveCache', -28810, 'Duplicate hash key', [], []),
-28809: ('liveCache', -28809, 'Invalid object column description', '', ''),
-28808: ('liveCache', -28808, 'Hash not found', [], []),
-28807: ('liveCache', -28807, 'No next object', '', ''),
-28806: ('liveCache', -28806, 'Nil page pointer', [], []),
-28805: ('liveCache', -28805, 'No BD lock', '', ''),
-28804: ('liveCache', -28804, 'Too old OID', [], []),
-28803: ('liveCache', -28803, 'Wrong object version', [], []),
-28802: ('liveCache', -28802, 'Wrong object version', [], []),
-28801: ('liveCache', -28801, 'Wrong class id', [], []),
-28534: ('liveCache', -28534, 'Package must be recreated', '', ''),
-28533: ('liveCache', -28533, 'Integer out of packed range', [], []),
-28532: ('liveCache', -28532, 'Version bound by transaction', [], []),
-28531: ('liveCache', -28531, 'OMS read only', [], []),
-28530: ('liveCache', -28530, 'omsTerminate called', [], []),
-28529: ('liveCache', -28529, 'Too small name buffer', [], []),
-28528: ('liveCache', -28528, 'Library not released', '', ''),
-28527: ('liveCache', -28527, 'Directory not found', [], []),
-28526: ('liveCache', -28526, 'Library not loaded', '', ''),
-28525: ('liveCache', -28525, 'Procedure Address not found', [], []),
-28524: ('liveCache', -28524, 'Duplicate schema', [], []),
-28523: ('liveCache', -28523, 'Unknown schema', [], []),
-28522: ('liveCache', -28522, 'Missing before image', [], []),
-28521: ('liveCache', -28521, 'Already in version', [], []),
-28520: ('liveCache', -28520, 'Object too long', '', ''),
-28519: ('liveCache', -28519, 'Registered class too long', '', ''),
-28518: ('liveCache', -28518, 'Not in Critical Section', [], []),
-28517: ('liveCache', -28517, 'Already in Critical Section', [], []),
-28516: ('liveCache', -28516, 'Commit or Rollback required', [], []),
-28515: ('liveCache', -28515, 'OMS Version already open', [], []),
-28514: ('liveCache', -28514, 'Unknown OMS Version', [], []),
-28513: ('liveCache', -28513, 'Method not found', '', ''),
-28512: ('liveCache', -28512, 'LocalServer not found', '', ''),
-28511: ('liveCache', -28511, 'InProcServer not found', '', ''),
-28510: ('liveCache', -28510, 'Typelib not found', '', ''),
-28509: ('liveCache', -28509, 'Progid not found', '', ''),
-28508: ('liveCache', -28508, 'Unsupported parameter type', [], []),
-28507: ('liveCache', -28507, 'Too many output parameters', '', ''),
-28506: ('liveCache', -28506, 'Wrong first Parameter', '', ''),
-28505: ('liveCache', -28505, 'No Component Object found', [], []),
-28504: ('liveCache', -28504, 'Component Guid not found in TypeLibrary', '', ''),
-28503: ('liveCache', -28503, 'Crash in DB-Procedure', [], []),
-28502: ('liveCache', -28502, 'Error writing OMS output stream', [], []),
-28501: ('liveCache', -28501, 'Error reading OMS input stream', [], []),
-28007: ('liveCache', -28007, 'OID not compatible with given class', [], []),
-28006: ('liveCache', -28006, 'Object not locked', [], []),
-28005: ('liveCache', -28005, 'Duplicate object', [], []),
-28004: ('liveCache', -28004, 'Unknown class identification', '', ''),
-28003: ('liveCache', -28003, 'Unknown GUID', [], []),
-28002: ('liveCache', -28002, 'Invalid OID', [], []),
-28001: ('liveCache', -28001, 'Access via NIL OID', [], []),
-28000: ('liveCache', -28000, 'Operator NEW failed', '', ''),
-27019: ('SQL class', -27019, 'Unicode/ASCII conversion failed', [], []),
-27018: ('SQL class', -27018, 'Connection error', [], []),
-27017: ('SQL class', -27017, 'Too many volumes', [], []),
-27016: ('SQL class', -27016, 'DB shut down', [], []),
-27015: ('SQL class', -27015, 'Connection down', [], []),
-27014: ('SQL class', -27014, 'Connect not ok', [], []),
-27013: ('SQL class', -27013, 'Command not available in this mode', '', ''),
-27012: ('SQL class', -27012, 'PREPARE not permitted for this statement', '', ''),
-27011: ('SQL class', -27011, 'Input variable has been truncated', '', ''),
-27010: ('SQL class', -27010, 'Invalid use of SQL::COPY operator', '', ''),
-27009: ('SQL class', -27009, 'Command too long', [], []),
-27008: ('SQL class', -27008, 'Missing variable address in SQLDA', '', ''),
-27007: ('SQL class', -27007, 'Too many parameters, SQLDA too short', '', ''),
-27006: ('SQL class', -27006, 'Incompatible data types', [], []),
-27005: ('SQL class', -27005, 'Parameter list too short', '', ''),
-27004: ('SQL class', -27004, 'Parameter list too long', '', ''),
-27003: ('SQL class', -27003, 'Numeric input parameter overflow', [], []),
-27002: ('SQL class', -27002, 'Invalid numeric input parameter value', '', ''),
-27001: ('SQL class', -27001, 'Input parameter cannot be NULL value', '', ''),
-27000: ('SQL class', -27000, 'Unknown error', [], []),
-25801: ('Replication Manager', -25801, 'Internal program error', ['An internal program error has occurred.'], ['Notify your ']),
-25507: ('Replication Manager', -25507, 'Error when reducing the file <file name>: <operating sys', ['An operating system-dependent text appears in the operating system error message, indicating the error that occurred. Reasons for the error may be that there is no file of this name or that the specified disk is write-protected, etc.'], ['Specify a different filename or correct the error at operating system level.']),
-25505: ('Replication Manager', -25505, 'Error when deleting the file <file name>: <operating sys', ['An operating system-dependent text appears in the operating system error message, indicating the error that occurred.'], ['No user action is required.']),
-25504: ('Replication Manager', -25504, 'Error when writing file', ['An operating system-dependent text appears in the operating system error message, indicating the error that occurred.'], ['Fix the cause of the error and restart the Loader to process the terminated command.']),
-25503: ('Replication Manager', -25503, 'Error when reading file', ['An operating system-dependent text appears in the operating system error message, indicating the error that occurred.'], ['Fix the cause of the error and restart the Loader to process the terminated command.']),
-25502: ('Replication Manager', -25502, 'Error when closing the file <file name>: <operating syst', ['An operating system-dependent text appears in the operating system error message, indicating the error that occurred.'], ['No user action is required.']),
-25501: ('Replication Manager', -25501, 'Error when opening the file <file name>: <operating syst', ['An operating system-dependent text appears in the operating system error message, indicating the error that occurred. Reasons for the error may be that there is no file of this name or that the specified disk is write-protected, etc.'], ['Specify a different filename or correct the error (at operating system level).']),
-25354: ('Replication Manager', -25354, 'Error in the command for uploading data; the LONG data f', ['This error occurs when uploading or updating data with the DATALOAD or DATAUPDATE command if all LONG values of a column that are to be inserted are in a LONG data file.'], ['Correct the data file and re-execute the command.']),
-25353: ('Replication Manager', -25353, 'Error when downloading data; the maximum number of LONG', ['Error when downloading data using the DATAEXTRACT command.'], ['Correct the statement and re-execute it.']),
-25352: ('Replication Manager', -25352, 'Error when downloading data; several errors occurred whe', ['Error when downloading data using the DATAEXTRACT command.'], ['Check the other error messages and correct the command and re-execute it.']),
-25351: ('Replication Manager', -25351, 'Error in command; the LONGFILE specification for the col', ['Error when downloading data using the DATAEXTRACT command.'], ['Correct the statement and re-execute it.']),
-25344: ('Replication Manager', -25344, 'Error in command; the output length specified for column', ['Error when downloading data using the DATAEXTRACT command.'], ['Correct the output length for the column specified and re-execute the command.']),
-25343: ('Replication Manager', -25343, 'Error in command; the SELECT statement in the command do', ['Error when downloading data using the DATAEXTRACT command.'], ['If you want to download these columns as well, you must include them in the SELECT command. If you do not want to download them, delete the column names from the column list.']),
-25342: ('Replication Manager', -25342, 'Error when restoring table <table name>; the structures', ['Error when uploading data using the TABLELOAD command.'], ['Change the structure of the target table so that it matches that of the source table. Execute the command again.']),
-25341: ('Replication Manager', -25341, 'Error when generating the CREATE TABLE/CREATE INDEX stat', ['Error when downloading data using the DATAEXTRACT FOR DATALOAD command.'], ['Rectify the cause of the error and re-execute the command.']),
-25340: ('Replication Manager', -25340, 'UCS2 conversion error; character string contains invalid', ['Error uploading or updating data using the DATALOAD, FASTLOAD, or DATAUPDATE command on a UNICODE database.'], ['Correct the rejected data and re-execute the command.']),
-25339: ('Replication Manager', -25339, 'Error when restarting the command; unable to open restar', ['Error when re-executing the TABLELOAD command for uploading data.'], ['Analyze and rectify the cause of the error. Execute the command again.']),
-25338: ('Replication Manager', -25338, 'Error when restarting the command; entry in assignment f', ['Error when re-executing the TABLELOAD command for uploading data.'], ['If possible, restore the assignment file to its original state. If this is not possible, you need to download and upload all the data again to ensure your data is consistent.']),
-25337: ('Replication Manager', -25337, 'Error when restoring table <table name>; the data file <', ['Error when uploading data using the TABLELOAD command.'], ['Download the table before you restore it.']),
-25336: ('Replication Manager', -25336, 'Error when restoring tables; the data file specified was', ['Error when uploading data using the TABLELOAD ALL or the TABLELOAD USER command.'], ['If you want to restore tables, first of all you must download them using the correct TABLEEXTRACT command (use the option ALL or USER):']),
-25335: ('Replication Manager', -25335, 'Error when restoring the table <table name>; the data fi', ['Error when uploading data using the TABLELOAD TABLE command.'], ['If you want to restore one particular table, you must download it using the TABLEEXTRACT command.']),
-25334: ('Replication Manager', -25334, 'The file counter exceeds the maximum of 9999 files', ['Error when downloading data using the TABLEEXTRACT command.'], ['Correct the default size for one single data file in the TABLEEXTRACT command and re-execute the command.']),
-25333: ('Replication Manager', -25333, 'Unable to extract index definition <SQL error text>', ['Error when downloading data using the TABLEEXTRACT command.'], ['Analyze the cause of the error and re-execute the command.']),
-25332: ('Replication Manager', -25332, 'Unable to extract table definition <SQL error text>', ['Error when downloading data using the TABLEEXTRACT command.'], ['Analyze the cause of the error and re-execute the command.']),
-25331: ('Replication Manager', -25331, 'This is a restricted statement, user must be SYSDBA', ['The commands TABLEEXTRACT ALL, TABLELOAD ALL, CATALOGEXTRACT ALL, and CATALOGLOAD ALL affect the whole database catalog and can therefore only be executed by a system administrator.'], ['Call the SAP DB Loader using the correct user ID or execute a USE-USER command with the correct user ID beforehand.']),
-25330: ('Replication Manager', -25330, 'Error when executing the command; the page sizes of the', ['Error when uploading data using the TABLELOAD command.'], ['No user action is possible. The data can only be loaded into a database with the same page size as the source database.']),
-25329: ('Replication Manager', -25329, 'Error when executing the command; the data file is corru', ['Error when uploading data using the TABLELOAD command.'], ['Create the data file using the TABLEEXTRACT command and re-execute the command.']),
-25328: ('Replication Manager', -25328, 'Error when executing the DATAEXTRACT command; the server', ['Error when downloading data using the DATAEXTRACT command.'], ["Check the problems that have occurred using the entries in the server's log file."]),
-25327: ('Replication Manager', -25327, 'Error when extracting data record <number of data record', ['Error when downloading data using the DATAEXTRACT command.'], ['Check the incorrect data records. ']),
-25326: ('Replication Manager', -25326, 'Error when executing the download command. The number ex', ['Error when downloading data using the DATAEXTRACT command.'], ['No user action required.']),
-25325: ('Replication Manager', -25325, 'Error in command; the external and internal data types a', ['Error when downloading data using the DATAEXTRACT command.'], ['Correct the statement and re-execute it.']),
-25324: ('Replication Manager', -25324, 'Error in the length specifications of the column descrip', ['Error when downloading data using the DATAEXTRACT command.'], ['Correct the statement and re-execute it.']),
-25323: ('Replication Manager', -25323, 'Error in command; the data type of the constant in the c', ['Error when downloading data using the DATAEXTRACT command.'], ['Correct the statement and re-execute it.']),
-25322: ('Replication Manager', -25322, 'Error in the command; the constant you entered was trunc', ['An error has occurred while uploading (DATALOAD or FASTLOAD) or updating data (DATAUPDATE).'], ['Correct the statement and re-execute it.']),
-25321: ('Replication Manager', -25321, 'Error in the command; the constant you have entered <val', ['An error has occurred while uploading (DATALOAD or FASTLOAD) or updating data (DATAUPDATE).'], ['Correct the statement and re-execute it.']),
-25320: ('Replication Manager', -25320, 'The LONG value could not be loaded into column <column n', ['An error has occurred while uploading (DATALOAD) or updating data (DATAUPDATE).'], ['Correct the cause of the error and re-execute the command.']),
-25319: ('Replication Manager', -25319, 'Unable to find any data for the column in the data file', ['Error when uploading data using the DATALOAD or FASTLOAD command.'], ['Check the data in the data file and re-execute the command.']),
-25318: ('Replication Manager', -25318, 'The generated system key has exceeded the maximum possib', ['Error when uploading data using the FASTLOAD command.'], ['No user action is possible.']),
-25317: ('Replication Manager', -25317, 'Entry for column <column name> is not compatible with th', ['An error has occurred while uploading (DATALOAD or FASTLOAD) or updating data (DATAUPDATE). '], ['Correct the data and re-execute the command.']),
-25316: ('Replication Manager', -25316, 'The FASTLOAD command cannot be executed; the table conta', ['Error when uploading data using the FASTLOAD command.'], ['Load the table with the DATALOAD command instead.']),
-25315: ('Replication Manager', -25315, 'The data type of the column <column name> and the extern', ['Error when downloading data using the DATAEXTRACT command. '], ['Select another external data type and re-execute the command.']),
-25314: ('Replication Manager', -25314, 'Too few decimal places defined for column <column name>;', ['Error when downloading data using the DATAEXTRACT command.'], ['Correct the specifications you made for the external display of this column and re-execute the command.']),
-25313: ('Replication Manager', -25313, 'Numerical value has been truncated', ['Error when downloading data using the DATAEXTRACT command.'], ['Check the data once it has been downloaded.']),
-25311: ('Replication Manager', -25311, 'Data missing for NOT NULL column <column name>', ['Error when uploading data using the FASTLOAD command.'], ['Correct the values or the command and re-execute the command.']),
-25310: ('Replication Manager', -25310, 'Column <column name> does not permit NULL values', ['An error has occurred while uploading (DATALOAD or FASTLOAD) or updating data (DATAUPDATE). '], ['Correct the data and re-execute the command.']),
-25309: ('Replication Manager', -25309, 'The value you entered was not recognized as a BOOLEAN en', ['An error has occurred while uploading (DATALOAD or FASTLOAD) or updating data (DATAUPDATE).'], ['Correct the data and re-execute the command.']),
-25308: ('Replication Manager', -25308, 'CONSTRAINT condition violated', ['Error when uploading data using the FASTLOAD command.'], ['Correct the data and re-execute the command.']),
-25306: ('Replication Manager', -25306, 'The value you have entered is not valid for hexadecimal', ['An error has occurred while uploading (DATALOAD or FASTLOAD) or updating data (DATAUPDATE).'], ['Correct the values and re-execute the command.']),
-25305: ('Replication Manager', -25305, 'The entries in the key fields are too long', ['Error when uploading data using the FASTLOAD command.'], ['Correct the data and re-execute the command.']),
-25304: ('Replication Manager', -25304, 'Key field entries are missing', ['Error when uploading data using the FASTLOAD command.'], ['Correct the data and re-execute the command.']),
-25303: ('Replication Manager', -25303, 'The values entered are not in the correct order', ['Error when uploading data using the FASTLOAD command.'], ['Correct the data and re-execute the command.']),
-25302: ('Replication Manager', -25302, 'The value entered is not a valid numerical value: <value', ['An error has occurred in the command for uploading (DATALOAD or FASTLOAD) or updating data (DATAUPDATE).'], ['Correct the values and re-execute the command.']),
-25301: ('Replication Manager', -25301, 'Invalid entry in Date or Time column', ['An error has occurred while uploading (DATALOAD or FASTLOAD) or updating data (DATAUPDATE).'], ['Correct the values and re-execute the command.']),
-25281: ('Replication Manager', -25281, 'Syntax error at a certain position', ['The Loader discovered a syntax error in the command when it was parsed.'], ['Correct the statement and re-execute it.']),
-25239: ('Replication Manager', -25239, 'The value specified is not a integer number', ['An error has occurred in the command for uploading (DATALOAD or FASTLOAD) or updating data (DATAUPDATE).'], ['Correct the statement and re-execute it.']),
-25238: ('Replication Manager', -25238, 'Error when executing the command; the command does not c', ['Error when updating data using the DATAUPDATE command.'], ['Correct the statement and re-execute it.']),
-25237: ('Replication Manager', -25237, 'Error when executing the command; the columns that are t', ['Error when updating data using the DATAUPDATE command.'], ['Correct the statement and re-execute it.']),
-25236: ('Replication Manager', -25236, 'Error in column description; column positions overlap', ['Error when downloading data using the DATAEXTRACT command.'], ['Correct the data and re-execute the command.']),
-25235: ('Replication Manager', -25235, 'Error in column description; identical positions for dif', ['Error when downloading data using the DATAEXTRACT command.'], ['Correct the data and re-execute the command.']),
-25234: ('Replication Manager', -25234, 'Error in column description; file format is FORMATTED, b', ['An error has occurred in the command for uploading (DATALOAD or FASTLOAD) or updating data (DATAUPDATE).'], ['Correct the positions you entered and re-execute the command.']),
-25233: ('Replication Manager', -25233, 'Error in column description; file format is COMPRESSED,', ['An error has occurred in the command for uploading (DATALOAD or FASTLOAD) or updating data (DATAUPDATE).'], ['Correct the positions you entered and re-execute the command.']),
-25232: ('Replication Manager', -25232, 'Unknown keyword', ['The command to upload or download data contains an error.'], ['Correct the statement and re-execute it.']),
-25231: ('Replication Manager', -25231, 'Specification of ROUND, TRUNC, or SCALE not allowed for', ['Error when uploading or downloading data.'], ['Correct the file information and re-execute the command.']),
-25230: ('Replication Manager', -25230, 'Error in DATAEXTRACT command; specification for command', ['Error when downloading data using the DATAEXTRACT command.'], ['Correct the file information and re-execute the command.']),
-25229: ('Replication Manager', -25229, 'Invalid relational operator in condition', ['The command to upload or download data contains an error.'], ['Correct the file information and re-execute the command.']),
-25228: ('Replication Manager', -25228, 'Invalid specification for external representation of dat', ['The command to upload or download data contains an error.'], ['Correct the file field type and re-execute the command.']),
-25227: ('Replication Manager', -25227, 'Maximum number of conditions in a command has been excee', ['The command to upload or download data contains an error.'], ['Correct the file field type and re-execute the command.']),
-25226: ('Replication Manager', -25226, 'Maximum number of column specifications in a command has', ['The command to upload or download data contains an error.'], ['Correct the file information and re-execute the command.']),
-25225: ('Replication Manager', -25225, 'Invalid specification for the representation of thousand', ['The command to upload or download data contains an error.'], ['Correct the file field type and re-execute the command.']),
-25224: ('Replication Manager', -25224, 'Invalid specification for language of messages; specify', ['The command to upload or download data contains an error.'], ['Correct the file field type and re-execute the command.']),
-25223: ('Replication Manager', -25223, 'Invalid specification for representation of NULL values', ['The command to upload or download data contains an error.'], ['Correct the file field type and re-execute the command.']),
-25222: ('Replication Manager', -25222, 'Invalid specification for Boolean display', ['The command to upload or download data contains an error.'], ['Correct the entries and re-execute the command.']),
-25221: ('Replication Manager', -25221, 'Invalid specification for representation of decimal numb', ['The command to upload or download data contains an error.'], ['Correct the entries and re-execute the command.']),
-25220: ('Replication Manager', -25220, 'Invalid separator/delimiter specification', ['The command to upload or download data contains an error.'], ['Correct the format and re-execute the command.']),
-25219: ('Replication Manager', -25219, 'Columns must be specified in the command in ascending or', ['Error in the command for uploading data.'], ['Correct the entries and re-execute the command.']),
-25218: ('Replication Manager', -25218, 'Invalid file format specification; no columns specified', ['The command to upload or download data contains an error.'], ['Correct the statement and re-execute it.']),
-25216: ('Replication Manager', -25216, 'File format FORMATTED required', ['The command to upload or download data contains an error.'], ['Correct the format and re-execute the command.']),
-25214: ('Replication Manager', -25214, 'Invalid file format specification; Separator/Delimiter i', ['The command to upload or download data contains an error.'], ['Correct the entries and re-execute the command.']),
-25213: ('Replication Manager', -25213, 'Invalid file format specification; FORMATTED and COMPRES', ['The command to upload or download data contains an error.'], ['Correct the format and re-execute the command.']),
-25212: ('Replication Manager', -25212, 'Invalid TRUNC specification; enter a value between 0 and', ['The command to upload or download data contains an error.'], ['Correct the number of rows you specified for TRUNC and re-execute the command.']),
-25211: ('Replication Manager', -25211, 'Invalid ROUND specification; specify a value between 0 a', ['The command to upload or download data contains an error.'], ['Correct the number of rows you specified for ROUND and re-execute the command.']),
-25210: ('Replication Manager', -25210, 'Invalid value for SCALE; enter a value between -127 and', ['The command to upload or download data contains an error.'], ['Correct the entry you made for SCALE and re-execute the command.']),
-25209: ('Replication Manager', -25209, 'Invalid value for FRACTION; specify a positive value', ['The command to upload or download data contains an error.'], ['Correct the entry you made for FRACTION and re-execute the command.']),
-25208: ('Replication Manager', -25208, 'Invalid position specification; enter positive values', ['The command to upload or download data contains an error.'], ['Correct the data and re-execute the command.']),
-25207: ('Replication Manager', -25207, 'Number of lines specified for USAGE is too high', ['An error has occurred in the FASTLOAD command.'], ['Correct your entries and re-execute the command.']),
-25206: ('Replication Manager', -25206, 'Invalid specification of lines for USAGE; value must be', ['An error has occurred in the FASTLOAD command.'], ['Correct the number of rows you specified for USAGE and re-execute the command.']),
-25205: ('Replication Manager', -25205, 'Invalid specification for USAGE; possible values are bet', ['An error has occurred in the FASTLOAD command.'], ['Correct the specified USAGE percentage and re-execute the command.']),
-25204: ('Replication Manager', -25204, 'Invalid length specification for ZONED field; possible', ['The command to upload or download data contains an error.'], ['Correct the file field type and re-execute the command.']),
-25203: ('Replication Manager', -25203, 'Invalid length specification for DECIMAL field; possibl', ['The command to upload or download data contains an error.'], ['Correct your entries and re-execute the command.']),
-25202: ('Replication Manager', -25202, 'Invalid length specification for REAL field; possible le', ['The command to upload or download data contains an error.'], ['Correct the file field type and re-execute the command.']),
-25201: ('Replication Manager', -25201, 'Invalid length specification for INTEGER field; possible', ['The command to upload or download data contains an error.'], ['Correct the data and re-execute the command.']),
-25109: ('Replication Manager', -25109, '<command> not implemented', ['The specified statement could not be executed because the required functions have not been installed on the Loader.'], ['No user action possible.']),
-25022: ('Replication Manager', -25022, 'Request to terminate operation received; processing of c', ['Using Ctrl C, the user has sent a request to the Loader to cancel the processing of statements.'], ['No user action is required.']),
-25021: ('Replication Manager', -25021, 'Error during user changeover', ['An error has occurred when downloading or uploading data using the commands TABLEEXTRACT ALL and TABLELOAD ALL.'], ['Rectify the cause of the error and re-execute the command.']),
-25020: ('Replication Manager', -25020, 'Memory full', ['A statement cannot be executed because of limited memory space.'], ['No user action possible.']),
-25019: ('Replication Manager', -25019, 'Error when opening the log file; temporary log file open', ["Attempts to open the Loader's log file failed. This may have been caused by another Loader already running on the same computer. If more than one Loader is started on one computer at the same time, only one can access the log file at a time because log files can only be opened exclusively."], ['No user action is required.']),
-25018: ('Replication Manager', -25018, 'Error when changing the authorizations for the log file;', ['This error only occurs when you execute the SET LOGOWNER <USERNAME> command on UNIX or Linux operating systems.'], ['Use the error text to determine why the modification failed. Rectify the error and re-execute the statement.']),
-25011: ('Replication Manager', -25011, 'Error when executing the internal SQL command', ['An SQL command generated by the Loader to process an upload or download command could not be executed. This message also displays the cause of the error.'], ['Fix the cause of the error and restart the Loader.']),
-25010: ('Replication Manager', -25010, '<SQL error text>', ["The database reports SQL errors that occur while a user's SQL commands are being processed with this error number."], ['Fix the cause of the error and restart the Loader.']),
-25009: ('Replication Manager', -25009, 'Failure in db communication', ['Communication between the Loader and the database takes place via the synchronous exchange of communication packages. The Loader sends a package containing the command that is to be processed to the database. This is known as a "request". While the database processes the command, the Loader waits for the package to be returned with the result. This is known as a "receive".'], ['Use the error text to determine why the communication failed. Fix the cause or the error and restart the Loader.']),
-25008: ('Replication Manager', -25008, "Error when logging on user; previous user's database con", ['An error occurred when a user attempted to log on to the database. The last user to have logged on has been logged on again instead.'], ['Since this message merely informs you that a previous connection has been restored, please proceed as described in message ']),
-25007: ('Replication Manager', -25007, 'Error when executing the command; no connection to the d', ['During the execution of an upload or download command or an SQL command, the system was unable to find a connection to the database. This may be because you are not logged on to the correct database.'], ['Before you execute load, unload, or SQL statements, log on to the database using the command ']),
-25006: ('Replication Manager', -25006, 'Error occurred when connecting to the database with spec', ['The system cannot create a connection to the database using the specified user data.'], ['Use the SQL error text to determine why the connection failed. Fix the cause or the error and restart the Loader.']),
-25005: ('Replication Manager', -25005, 'Error when logging user on to the database', ['The user specified could not be logged on to the database. '], ['Use the SQL error text to determine why the log on attempt failed. Fix the cause or the error and restart the Loader.']),
-25004: ('Replication Manager', -25004, 'Error when connecting to the database', ['The system cannot open a connection to the database.'], ['Use the SQL error text to determine why the connection failed. Fix the cause of the problem, and restart the Loader.']),
-25003: ('Replication Manager', -25003, 'Name of database host could not be determined', ['In a statement for opening a connection, no database host is specified. The database host could not be determined.'], ['In the statement for setting up a connection from the database instance to the Loader, enter the name of the host on which the database instance is running. Restart the Loader.']),
-24999: ('DB Manager', -24999, 'ERR - common error', ['An error has occurred that the Database Manager cannot analyze properly.'], ['Please inform your ']),
-24998: ('DB Manager', -24998, 'ERR_NOTIMPL - sorry, command not yet implemented', [], []),
-24997: ('DB Manager', -24997, 'ERR_FILE - file handling error', [], []),
-24996: ('DB Manager', -24996, 'ERR_PARAM - wrong parameters', [], []),
-24995: ('DB Manager', -24995, 'ERR_MEM - memory allocation error', [], []),
-24994: ('DB Manager', -24994, 'ERR_RTE - runtime environment error', ['The database runtime environment was unable to perform a function correctly.'], ['Please read the additional runtime environment error message.']),
-24993: ('DB Manager', -24993, 'ERR_RTEEXT - runtime environment error', ['The database runtime environment was unable to perform a function correctly.'], ['Please read the additional runtime environment error message.']),
-24992: ('DB Manager', -24992, 'ERR_NOUTILSESSION - no utility session available', [], []),
-24991: ('DB Manager', -24991, 'ERR_ NOSQLUSERSESSION - no sql user session available', [], []),
-24990: ('DB Manager', -24990, 'ERR_ NOBACKUPSESSION - no backup session available', [], []),
-24989: ('DB Manager', -24989, 'ERR_NOHISTORYSESSION - no backup history session availab', [], []),
-24988: ('DB Manager', -24988, 'ERR_SQL - sql error', ['An error occurred when a command was issued to the database kernel.'], ['If necessary, consult the other database-kernel error message and correct your entries accordingly.']),
-24987: ('DB Manager', -24987, 'ERR_TOSMALL - packet size too small for answer', [], []),
-24986: ('DB Manager', -24986, 'ERR_NOMEDIA - media file not found', [], []),
-24985: ('DB Manager', -24985, 'ERR_MENOTFOUND - medium not found', ['The medium you have specified has not been defined.'], ['Check your entries. Use another medium or create a new one with that name.']),
-24984: ('DB Manager', -24984, 'ERR_MENOVALID - invalid medium definition', ['The medium you have defined is invalid.'], ['Check the parameters you have entered.']),
-24983: ('DB Manager', -24983, 'ERR_BANOVALIDTYPE - invalid backup type', [], []),
-24982: ('DB Manager', -24982, 'ERR_ERR_NOHISTORY - backup history file not found', ['No backup history exists.'], ['A backup history only exists if backup operations have already been executed. The backup history function cannot be used before this has been done.']),
-24981: ('DB Manager', -24981, 'ERR_HIENTRYNOTFOUND - backup history entry not found', [], []),
-24980: ('DB Manager', -24980, 'ERR_NOHELP - xparam help file not found', [], []),
-24979: ('DB Manager', -24979, 'ERR_XPNOTFOUND - parameter not found', ['The parameter specified does not exist in the parameter help file.'], ['Check that the parameter name is correct. Bear in mind that statements are case-sensitive.']),
-24978: ('DB Manager', -24978, 'ERR_XPSYNTAX - xparam syntax error', ['The parameter description in the parameter help file is incorrect.'], ['Read the extended error text and correct the error in the file ']),
-24977: ('DB Manager', -24977, 'ERR_COMMAND - unknown command <command>', [], []),
-24976: ('DB Manager', -24976, 'ERR_PARAMEXIST - param file of database already exists', [], []),
-24975: ('DB Manager', -24975, 'ERR_NOXPSESSION - param session inactive', [], []),
-24974: ('DB Manager', -24974, 'ERR_XPSESSION - param session active', [], []),
-24973: ('DB Manager', -24973, 'ERR_XPCHECK - param check failure/request', [], []),
-24972: ('DB Manager', -24972, 'ERR_XPINVCONF - invalid value', [], []),
-24971: ('DB Manager', -24971, 'ERR_XPNOCHECK - no running parameter check', ['A reset status was not possible after correcting a single parameter because no check run was active when the parameters were checked.'], ['Start the parameter check again.']),
-24970: ('DB Manager', -24970, 'ERR_XPNOMODIFY - parameter must not be modified', ['The kernel parameter used cannot be modified.'], ['Set the parameter back to its initial value.']),
-24969: ('DB Manager', -24969, 'ERR_XPDIRTY - param file is dirty', ['An attempt has been made to make a change to the kernel parameters without first checking whether or not a previous change works properly by restarting the database.'], ['Restart the database and change the parameters again. ']),
-24968: ('DB Manager', -24968, 'ERR_XPREADONLY - parameter is read only', ['The parameter used cannot be modified.'], ['Correct your entry.']),
-24967: ('DB Manager', -24967, 'ERR_SYSTEM - system call error', ['An attempt to use an operating system function has failed.'], ['Read the extended error text which describes operating system messages in more detail.']),
-24966: ('DB Manager', -24966, 'ERR_LOGON - logon to DBM server failed', [], []),
-24965: ('DB Manager', -24965, 'ERR_SYSLOGON - logon to system failed', [], []),
-24964: ('DB Manager', -24964, 'ERR_EXECUTE - error in program execution', [], []),
-24963: ('DB Manager', -24963, 'ERR_DEVCHECK - error while checking volume', ['The volume you have tried to configure is invalid. The system was unable to find/create a volume with the parameters specified.'], ['Check your entries and the configuration of your operating system. Make corrections as appropriate and reconfigure the volume.']),
-24962: ('DB Manager', -24962, 'ERR_DEVTYPE - wrong volume type', ['An unknown or invalid volume type has been used.'], ['Correct your entry.']),
-24961: ('DB Manager', -24961, 'ERR_STATE - cannot determine current db state', ['The status of the database ('], ['Check the status of the database processes using the operating system tools. Try to connect to the database through a database application, for example, SQL Studio. If this succeeds, the database has the status ']),
-24960: ('DB Manager', -24960, 'ERR_DBRUN - database is running', [], []),
-24959: ('DB Manager', -24959, 'ERR_XPOVERFLOW - value out of margin', ['The value used for a kernel parameter is invalid. You have either chosen an invalid data type (for example, you have used text for a numerical parameter) or you have exceeded the maximum values allowed for that data type (for example, you have used too large a number or too much text).'], ['Correct your entry.']),
-24958: ('DB Manager', -24958, 'ERR_BAOVERWRITE - file already exists, cannot overwrite', ['An attempt has been made to perform a Save. However, the medium that you specified has already been used for a Save, and has been defined as Not overwritable.'], ['Use a different save medium or delete the existing one using the operating system tools. Alternatively, you could also adjust the medium definition. ']),
-24957: ('DB Manager', -24957, 'ERR_NOUSER - required user not set', [], []),
-24956: ('DB Manager', -24956, 'ERR_BASAVETYPECON - backup type conflicts with medium de', ['An attempt has been made to Save or Restore using the defined medium. However, the predefined save type for the medium ('], ['Correct your entry or the medium definition. ']),
-24955: ('DB Manager', -24955, 'ERR_BANOSAVETYPE - backup type not defined', ['The medium definition contains no backup type ('], ['Correct the medium definition, or enter the backup type explicitly for the failed command.']),
-24954: ('DB Manager', -24954, 'ERR_BANOAUTOMED - no autolog medium found in media list', ['You have not defined an autosave medium to back up the log automatically.'], ['Correct the medium definition, or enter the backup medium explicitly for the failed command.']),
-24953: ('DB Manager', -24953, 'ERR_DBEXIST - database instance already exists', [], []),
-24952: ('DB Manager', -24952, 'ERR_USRSAVE - could not save user data', [], []),
-24951: ('DB Manager', -24951, 'ERR_USRREAD - could not read user data', [], []),
-24950: ('DB Manager', -24950, 'ERR_USRFAIL - user authorization failed', [], []),
-24949: ('DB Manager', -24949, 'ERR_USREXISTS - user entry already exists', [], []),
-24948: ('DB Manager', -24948, 'ERR_NODBNAME - database name required', [], []),
-24947: ('DB Manager', -24947, 'ERR_DBNAME - do not use dbname', [], []),
-24946: ('DB Manager', -24946, 'ERR_TOMANYPARAM - to many parameters', [], []),
-24945: ('DB Manager', -24945, 'ERR_TOFEWPARAM - to few parameters', [], []),
-24944: ('DB Manager', -24944, 'ERR_USRDELSELF - cannot delete current user', [], []),
-24943: ('DB Manager', -24943, 'ERR_USRDELCOLD - cannot delete DBM user', [], []),
-24942: ('DB Manager', -24942, 'ERR_USRDELSDBA - cannot delete sysdba', [], []),
-24941: ('DB Manager', -24941, 'ERR_NEEDLOGON - DBM server logon required', [], []),
-24940: ('DB Manager', -24940, 'ERR_NEEDSYSLOGON - system logon required', [], []),
-24939: ('DB Manager', -24939, 'ERR_LASTREG - cannot delete last registration of instanc', [], []),
-24938: ('DB Manager', -24938, 'ERR_NOENTRY - no entry found', [], []),
-24937: ('DB Manager', -24937, 'ERR_MISSRIGHT - no server rights for this command', [], []),
-24936: ('DB Manager', -24936, 'ERR_DBNORUN - database is not running', [], []),
-24935: ('DB Manager', -24935, 'ERR_NOUSERS - no users found', [], []),
-24934: ('DB Manager', -24934, 'ERR_VERSION - incompatible versions (param and kernel)', [], []),
-24933: ('DB Manager', -24933, 'ERR_NOSERVICESESSION - no service kernel available', [], []),
-24932: ('DB Manager', -24932, 'ERR_XPMIN - parameter value smaller than minimum allowed', [], []),
-24931: ('DB Manager', -24931, 'ERR_XPMIN - parameter value smaller than minimum allowed', [], []),
-24930: ('DB Manager', -24930, 'ERR_XPVALUESET - parameter value not in value set', [], []),
-24929: ('DB Manager', -24929, 'ERR_USRFRM - invalid user record format', [], []),
-24928: ('DB Manager', -24928, 'ERR_NOREPLY - no reply available', ['There is no response to an asynchronous request sent to the database instance.'], ['Repeat the statement until there is a response, and then use the statement that corresponds to the request to retrieve the response. Alternatively, you can immediately use the statement for retrieving the response. This statement waits until the response is provided.']),
-24927: ('DB Manager', -24927, 'ERR_TOOLCHK: external backup tool not found', ['The external backup tool was not found or is not correctly installed.'], []),
-24926: ('DB Manager', -24926, 'ERR_MEDIUMCHK: medium cannot be used with this external', [], []),
-24925: ('DB Manager', -24925, 'ERR_PREPARE: preparation of backup operation failed', ['The preparations required to implement the backup tool could not be successfully completed.'], []),
-24924: ('DB Manager', -24924, 'ERR_DBREQ: cannot start database kernel request', ['The database was unable to start the backup, check, or restore process.'], ['Attempt to fix the problem with the help of the extended error description. If you cannot solve the problem, contact you ']),
-24923: ('DB Manager', -24923, 'ERR_TOOLREQ: error while starting external backup tool', ['It was not possible to start a backup tool correctly.'], ['Attempt to fix the problem with the help of the extended error description. If you cannot solve the problem, contact you ']),
-24922: ('DB Manager', -24922, 'ERR_OPCHK: cannot check state of backup operation', ['You were unable to check the status of the database or the backup tool.'], ['Attempt to fix the problem with the help of the extended error description. If you cannot solve the problem, contact you ']),
-24921: ('DB Manager', -24921, 'ERR_POSTOP: error while finishing backup operation', ['It was not possible to perform the necessary postprocessing steps after a successful backup, check, or restore.'], ['Try to fix the problem with the help of the extended error description, and repeat the backup, check, or restore. If you cannot solve the problem, contact you ']),
-24920: ('DB Manager', -24920, 'ERR_BACKUPOP: backup operation was unsuccessful', ['The backup, check or restore action failed due to problems with either the database or the backup tool. If it is a backup check that has failed, this may have been caused by errors in the relevant backup.'], ['Attempt to fix the problem with the help of the extended error description. If you cannot solve the problem, contact you ']),
-24919: ('DB Manager', -24919, 'ERR_CLEANUP: cannot free all operational resources after', ['It was not possible to free all of the temporary system resources that were used for a successful backup, check, or restore.'], ['Check which resources were not released using the external backup log. If the resources are temporary files or pipes, try to remove these manually. You should also attempt to fix the problem with the help of the extended error description. If you cannot solve the problem, contact you ']),
-24918: ('DB Manager', -24918, 'ERR_MISSMIRR - missing data for mirror volume', ['The information for a mirror volume is missing.'], ['Correct your entry by specifying the data for the mirrored volume. Execute the command again.']),
-24917: ('DB Manager', -24917, 'ERR_MAXDATA - max data size exceeded', ['The total size of the data devspaces exceeds the current maximum value. '], ['Reduce the size of the devspaces to add. ']),
-24916: ('DB Manager', -24916, 'ERR_MAXDEVCNT - max device count exceeded', ['The number of devspaces of the type used exceeds the current maximum value.'], ['Increase the value of the database instance parameters MAXARCHIVELOGS for the log devspaces, or the value for MAXDATADEVISES for the data devspaces. To activate the new value, restart the database.']),
-24915: ('DB Manager', -24915, 'ERR_NOADDD - configuration update not allowed (param fil', [], []),
-24914: ('DB Manager', -24914, 'ERR_KEYEXISTS - installation key <key> exists', [], []),
-24913: ('DB Manager', -24913, 'ERR_SERVICEDB - can not register service kernel for <ins', ['The service database cannot be registered. This could be because the files were incorrectly installed or the operating system user does not have the necessary authorizations.'], ['Correct or repeat the installation or provide your operating system user with the required authorizations.']),
-24912: ('DB Manager', -24912, 'ERR_WRONGINST \226 DBM server instroot is <instroot>', [], []),
-24911: ('DB Manager', -24911, 'ERR_INVDBNAME - database name <dbname> is reserved', ['You selected an invalid name for your database.'], ['Use a different name for your database.']),
-24910: ('DB Manager', -24910, 'ERR_PARAMVER - wrong version of param help file (cserv.p', [], []),
-24909: ('DB Manager', -24909, 'ERR_DBAUNKNOWN - SYSDBA unknown', [], []),
-24908: ('DB Manager', -24908, 'ERR_DOMPUNKNOWN - DOMAIN password unknown', [], []),
-24907: ('DB Manager', -24907, 'ERR_DBAWRONG - wrong SYSDBA', [], []),
-24906: ('DB Manager', -24906, 'ERR_EBFDIRTY: invalid format of external backup history', ['The External Backup History file is not in the expected format.'], ['Depending on whether you require the information in this file or not, either contact your ']),
-24905: ('DB Manager', -24905, 'ERR_NOEBIDLIST: no information on external backup IDs av', ['No information on external backup IDs is available, since this information was not requested from an external backup tool.'], ['Execute the backup_ext_ids_get command to request this information.']),
-23203: ('SQL Studio', -23203, 'Cannot show tables of users, wrong database version!', ['The system table DOMAIN.TABLES does not contain all the columns required to display the tables in the catalog tree structure.'], ['Use a newer version of SQL Studio.']),
-23202: ('SQL Studio', -23202, 'Could not load object description !', ['The SQL Studio objects could not be loaded.'], ['Load the system tables with the database tools DBMGui or DBMCli.']),
-23201: ('SQL Studio', -23201, 'No ODBC driver!', ['There is no ODBC driver (sqlod32.dll, sqlsp32.dll) in the SQL Studio directory.'], ['Uninstall SQL Studio and reinstall it again.']),
-23200: ('SQL Studio', -23200, 'No data sources!', [], []),
-23104: ('SQL Studio', -23104, 'Could not load table definition!', ['The definition of a table could not be loaded.'], ['Contact your ']),
-23103: ('SQL Studio', -23103, 'Failed to create DBC Handle!', ['Could not create a database connection pool.'], ['Contact your ']),
-23102: ('SQL Studio', -23102, 'Failed to create DBC Pool!', ['Could not create a database connection pool.'], ['Contact your ']),
-23101: ('SQL Studio', -23101, 'Data in clipboard truncated!', ['When the contents of a Long column are exported into the clipboard, a maximum of 1048576 bytes are transferred. If there is more data than this in the results, it will be ignored.'], ['To export all contents of a Long column, that is, even if it amounts to more than 1048576 bytes, use the export in a file.']),
-23100: ('SQL Studio', -23100, 'OLE Error ! Please restart SQL Studio !', [], []),
-23072: ('SQL Studio', -23072, 'Representation of NULL value too long!', [], ['Choose a NULL value display with less than 16 characters.']),
-23071: ('SQL Studio', -23071, 'Convert object created by older SQL Studio version?', ['You can convert the SQL Studio object into a format that is compatible with a more up-to-date version of the SQL Studio.'], ['Choose Yes if you want to convert the object. Saving the object gives it the same format as the more up-to-date version of the SQL Studio. Once the object has been converted, you can no longer process it with an older version of the SQL Studio.']),
-23070: ('SQL Studio', -23070, 'Cannot open object created by newer SQL Studio Version!', ['You tried to open an SQL Studio object that was created with a newer version of the software.'], ['You can only modify this object using a newer version of the software. Install the most up-to-date version of the SQL Studio.']),
-23064: ('SQL Studio', -23064, 'Import failed!', ['Could not load exported SQL Studio objects.'], ['Contact your ']),
-23063: ('SQL Studio', -23063, 'Could not create Global Com Object!', ['An SQL studio object could not be created.'], ['End the SQL studio.']),
-23062: ('SQL Studio', -23062, 'Could not open connection !', ['The attempt to establish a connection to the database failed.'], ['Check the database status (tools: dbmcli, dbmgui).']),
-23061: ('SQL Studio', -23061, 'Cannot analyze error!', ['An ODBC error has occurred that could not be analyzed.'], ['Check which version of the ODBC driver you are using and install a more recent version if necessary.']),
-23060: ('SQL Studio', -23060, 'You don not have permission to delete this object!', ['You cannot delete an SQL Studio object that has been released by someone else.'], ['Contact the owner of the SQL Studio object.']),
-23059: ('SQL Studio', -23059, 'You don not have permission to modify this object!', ['You cannot modify an SQL Studio object that has been released by someone else.'], ['Contact the owner of the SQL Studio object.']),
-23058: ('SQL Studio', -23058, 'No database connection!', ['The connection to the database has been broken.'], ['Check the status of the database using the tools dbmcli and dbmgui.']),
-23057: ('SQL Studio', -23057, 'Reconnect failed!', ['An attempt to restore an interrupted connection to the database has failed.'], ['Check the status of the database using the tools dbmcli and dbmgui.']),
-23056: ('SQL Studio', -23056, 'User is exclusive!', [], []),
-23055: ('SQL Studio', -23055, 'Connection failed!', [], []),
-23054: ('SQL Studio', -23054, 'Maximum number of windows reached!', [], []),
-23053: ('SQL Studio', -23053, 'Cannot load suppose list!', ['The SQL support could not be loaded.'], ['Reload the system tables using the tools dbmcli or dbmgui.']),
-23052: ('SQL Studio', -23052, 'Could not save object data!', ['An SQL Studio object could not be saved.'], ['Reload the system tables using the tools dbmcli or dbmgui.']),
-23051: ('SQL Studio', -23051, 'Could not load system tables for SQL Studio!', ['The database does not contain the system tables needed for the SQL Studio.'], ['Reload the system tables using the tools dbmcli or dbmgui.']),
-23050: ('SQL Studio', -23050, 'Unknown error!', ['An unknown error has occurred.'], ['Contact your ']),
-22005: ('SQL', -22005, 'Connection timeout occurred. Session reconnected', ['The user transaction was terminated and rolled back by an implicit ROLLBACK statement. The database session was terminated because the user failed to carry out any operations during a certain period of time (installation parameter SESSION_TIMEOUT or the TIMEOUT value specified in the <CONNECT statement>). '], ['All commands having a result set (CURSOR) must be executed again in order to ensure that the result sets are built up again. If the connection is set to SQL_AUTOCOMMIT_OFF, all the other commands that were in an open transaction must also be executed again.']),
-22000: ('SQL', -22000, 'Null values not allowed on more than one long column', ['In an INSERT or UPDATE command, at most one long column may have the value NULL if long columns are inserted with the functions '], ['Only include one long column in the command or use empty strings instead of NULL values.']),
-9999: ('SQL', -9999, 'System error: Otherwise unknown errorcode', '', ''),
-9809: ('SQL', -9809, 'Option CHECK usage add error', ['When the option CHECK is specified, the SYSUSAGE entries for SQL-PL, FORM, REPORT, PROC, QUERY, COMMAND and PREPARE are maintained at the end of a precompiler run. An error occurred in this case.'], ['For error analysis and correction, pay attention to all error messages output during the precompiler run. For further information refer to the corresponding error numbers in this manual.']),
-9808: ('SQL', -9808, 'SET FORMAT error', ['An implicit SET FORMAT is issued to the database after every CONNECT. This determines which date and time formats are used. If an error occurs at the SET FORMAT command, the database standard format is taken as default.'], ['Restart the program and thereby avoid the error. If the SET FORMAT error occurs repeatedly, notify the database administrator.']),
-9807: ('SQL', -9807, 'Too many users', ['All sessions of the database are occupied.'], ['Wait until a session is released. If this problem arises frequently, the configuration of the database must be checked and modified by the database administrator.']),
-9806: ('SQL', -9806, 'Invalid output value', ['The define byte in the command buffer is set to an invalid value.'], ['Check whether the kernel and the precompiler used for translating the application have the same version number. If the version numbers agree, notify your database administrator.']),
-9805: ('SQL', -9805, 'Option CHECK usage on or off error', ['When the option CHECK is specified, the SYSUSAGE entries are maintained at the end of a precompiler run. An error occurred in this case.'], ['For error analysis and correction, pay attention to all error messages output during the precompiler run. For further information refer to the corresponding error numbers in this manual.']),
-9803: ('SQL', -9803, 'Unknown data type', ['The data type is not known in the database.'], ['Please inform your ']),
-9801: ('SQL', -9801, 'Invalid command state', ['The command state is invalid. '], ['Please inform your ']),
-9500: ('SQL', -9500, 'System error: RT Info standby not found', '', ''),
-9414: ('SQL', -9414, 'System error: Configuration parameter error', '', ''),
-9412: ('SQL', -9412, 'System error: MB Qual too short', '', ''),
-9411: ('SQL', -9411, 'System error: AK Too many intern parsinfos', '', ''),
-9409: ('SQL', -9409, 'System error: AK Invalid segment construction', '', ''),
-9408: ('SQL', -9408, 'System error: AK Unitrans SRC too short', '', ''),
-9406: ('SQL', -9406, 'System error: DDL trigger failed', '', ''),
-9405: ('SQL', -9405, 'System error: AK Datapart too short', '', ''),
-9404: ('SQL', -9404, 'System error: AK System error', '', ''),
-9402: ('SQL', -9402, 'System error: AK Unexpected strategy information', '', ''),
-9400: ('SQL', -9400, 'System error: AK Cachedirectory full', '', ''),
-9232: ('SQL', -9232, 'System error: KB Nil transindex', '', ''),
-9231: ('SQL', -9231, 'System error: KB Invalid server MB', '', ''),
-9229: ('SQL', -9229, 'System error: KB Too many child process requests', '', ''),
-9228: ('SQL', -9228, 'System error: KB Queue mismatch', '', ''),
-9226: ('SQL', -9226, 'System error: KB Skip key update', '', ''),
-9224: ('SQL', -9224, 'System error: KB Net error', '', ''),
-9221: ('SQL', -9221, 'System error: KB Net response timeout', '', ''),
-9212: ('SQL', -9212, 'System error: KB RESTART incomplete', '', ''),
-9211: ('SQL', -9211, 'System error: KB Stack type illegal', '', ''),
-9210: ('SQL', -9210, 'System error: KB Stack op illegal', '', ''),
-9209: ('SQL', -9209, 'System error: KB Log error', '', ''),
-9206: ('SQL', -9206, 'System error: AK Duplicate catalog information', '', ''),
-9205: ('SQL', -9205, 'System error: AK Catalog information not found', '', ''),
-9203: ('SQL', -9203, 'System error: KB Skip upd', '', ''),
-9202: ('SQL', -9202, 'System error: KB Enough resultsets', '', ''),
-9111: ('SQL', -9111, 'System error: Move error', '', ''),
-9055: ('SQL', -9055, 'System error: BD Long column missing', '', ''),
-9053: ('SQL', -9053, 'System error: BD Data page corrupted', '', ''),
-9051: ('SQL', -9051, 'System error: BD Invalid FBM mark', '', ''),
-9049: ('SQL', -9049, 'System error: BD Primkey from inv in primtree not found', '', ''),
-9047: ('SQL', -9047, 'System error: BD Invalid filetype', '', ''),
-9046: ('SQL', -9046, 'System error: BD No converter entry', '', ''),
-9045: ('SQL', -9045, 'System error: BD Root check', '', ''),
-9044: ('SQL', -9044, 'System error: BD Inconsistent nodetype', '', ''),
-9043: ('SQL', -9043, 'System error: BD Fdir access not allowed', '', ''),
-9042: ('SQL', -9042, 'System error: BD Append not allowed', '', ''),
-9041: ('SQL', -9041, 'System error: BD Index not accessible', '', ''),
-9040: ('SQL', -9040, 'System error: BD Dropping of fdir not allowed', '', ''),
-9030: ('SQL', -9030, 'System error: BD Bad logpage', '', ''),
-9029: ('SQL', -9029, 'System error: BD Bad invfile', '', ''),
-9028: ('SQL', -9028, 'System error: BD Bad file', '', ''),
-9027: ('SQL', -9027, 'System error: BD Bad fdir', '', ''),
-9026: ('SQL', -9026, 'System error: BD Bad datapage', '', ''),
-9024: ('SQL', -9024, 'System error: BD Invalid entrypos', '', ''),
-9023: ('SQL', -9023, 'System error: BD Illegal entrypos', '', ''),
-9020: ('SQL', -9020, 'System error: BD Init missing', '', ''),
-9019: ('SQL', -9019, 'System error: BD Buffer limit', '', ''),
-9018: ('SQL', -9018, 'System error: BD Page in wrong tree', '', ''),
-9016: ('SQL', -9016, 'System error: BD No prev invkey', '', ''),
-9015: ('SQL', -9015, 'System error: BD No next invey', '', ''),
-9014: ('SQL', -9014, 'System error: BD Invalid leaves structure', '', ''),
-9013: ('SQL', -9013, 'System error: BD Invalid index structure', '', ''),
-9012: ('SQL', -9012, 'System error: BD Inv not found', '', ''),
-9011: ('SQL', -9011, 'System error: BD Inv list not found', '', ''),
-9010: ('SQL', -9010, 'System error: BD Invalid invlistpos', '', ''),
-9008: ('SQL', -9008, 'System error: BD Illegal record', '', ''),
-9007: ('SQL', -9007, 'System error: BD Illegal page no', '', ''),
-9006: ('SQL', -9006, 'System error: BD Illegal keylength', '', ''),
-9005: ('SQL', -9005, 'System error: BD Illegal key', '', ''),
-9004: ('SQL', -9004, 'System error: BD Illegal file name', '', ''),
-9003: ('SQL', -9003, 'System error: BD Illegal entrylength', '', ''),
-9002: ('SQL', -9002, 'System error: BD Illegal branchlength', '', ''),
-9001: ('SQL', -9001, 'System error: BD Invalid root', '', ''),
-9000: ('SQL', -9000, 'SYSTEM ERROR: NOT YET IMPLEMENTED', ['This SQL statement is not yet implemented. It will be available in future releases.'], ['To achieve the desired effect try one or more other SQL statements.']),
-8888: ('SQL', -8888, 'SERVERDB not accessible', ['The attempt was made to start a session. This is impossible for one of the following reasons: '], ['\240']),
-8050: ('SQL', -8050, 'Migration error', ['An error has occurred while migrating a database instance with a database catalog stored in ASCII format (database parameter '], ['The action you need to take depends on what caused the error:']),
-8049: ('SQL', -8049, 'Prepare migration required', [], []),
-8048: ('SQL', -8048, 'Version of component must be compatible with kernel versi', ['You tried to use a component whose release number is much smaller than that of the database kernel used. Since the interface between the components and the database kernel has changed significantly, this is not possible.'], ['Use a component whose release number corresponds to that of the database kernel used.']),
-8047: ('SQL', -8047, 'Password required', ['With a <SET statement> you tried to activate a role which requires the definition of a password.'], ['Repeat the SQL statement, also specifying the password.']),
-8046: ('SQL', -8046, 'Conversion from UNICODE impossible', ['You tried to convert data in UCS-2 format (see also '], ['Check whether the data is correct.']),
-8045: ('SQL', -8045, 'Conversion to UNICODE impossible', ['You tried to convert data in ASCII format (see also '], ['You cannot perform a conversion explicitly. You can try to avoid this error by explicitly converting the UCS-2 data used, for example, for comparisons.']),
-8044: ('SQL', -8044, 'Conversion for character set value impossible', ['You tried to convert data in ASCII or UCS-2 format (see also '], ['You cannot perform a conversion explicitly. You can try to avoid this error by explicitly converting the data used, for example, for comparisons.']),
-8040: ('SQL', -8040, 'Key does not exist', ['The attempt was made to delete the key for the specified table. The specified table has no user-defined key. The key implicitly generated with the column SYSKEY cannot be deleted.'], ['The SQL statement is not needed because there is already the desired table definition.']),
-8039: ('SQL', -8039, 'Snapshot log does not exist', ['The attempt was made to delete the snapshot log for the specified table. The specified table has no snapshot log.'], ['The SQL statement is not needed because there is already the desired result.']),
-8037: ('SQL', -8037, 'DB procedure must be recompiled', ['SQL statements for data definition were performed which concern tables used in the DB procedure. Check by compilation whether the DB procedure is still executable.'], ['This check can only be made by the owner of the DB procedure by restoring the DB procedure.']),
-8035: ('SQL', -8035, 'Foreign key must exist', ['An <UPDATE statement> was performed for an updatable join view table. This <UPDATE statement> leads to an internal insert into one of the underlying base tables. The specifications made in the <UPDATE statement> are not sufficient to form all mandatory columns which are needed for the implicit <INSERT statement>.'], ['Issue an <INSERT statement> on the underlying base table. This can prevent the necessity of inserting when performing the <UPDATE statement> on the join view table.']),
-8034: ('SQL', -8034, 'Order column must be number', ['In a QUERY EXPRESSION with at least a UNION, INTERSECT or EXCEPT specification, the ORDER CLAUSE must not contain any COLUMN SPECs.'], ['Replace the column specifications by the corresponding numbers of the output columns.']),
-8033: ('SQL', -8033, 'Incomplete log segment', ['You tried to save the log. However, the log is smaller than defined in the installation parameter LOG_SEGMENT_SIZE.'], ['No action required.']),
-8032: ('SQL', -8032, 'Table must be a snapshot table', ['A <DROP SNAPSHOT statement> or <REFRESH statement> was specified. The specified name does not denote a snapshot table.'], ['Use a <QUERY statement> issued on the system table DOMAIN.TABLES to find out the existing snapshot tables.']),
-8031: ('SQL', -8031, 'Owner must be specified', ['In a database procedure the OWNER must be specified for each TABLE NAME.'], ['Correct the database procedure accordingly.']),
-8030: ('SQL', -8030, 'Column must be indexed', ['No index was created on the specified column.'], ['You can display a list of existing indexes using a QUERY statement based on the system table SYSODBCINDEXES. Create the desired index, or do without the index.']),
-8029: ('SQL', -8029, 'No servers installed', '', ''),
-8028: ('SQL', -8028, 'UNION columns must be compatible', ['In a <QUERY EXPRESSION> with at least a UNION, INTERSECT or EXCEPT specification, all sequences of SELECT COLUMNS must designate the same number of columns. The data types of the corresponding columns must thereby comply with the conditions valid for comparability.'], ['Use a QUERY statement issued on the system table DOMAIN.COLUMNS to find out the current definition of the affected columns. It may be attempted to achieve comparability by applying a <CONVERSION function>. ']),
-8025: ('SQL', -8025, 'Table must be temp table', ['In a <CREATE TABLE statement>, the option IGNORE ROLLBACK was specified for a permanent table. This is not allowed.'], ['You can repeat the SQL statement. To do this you either need to deselect the option IGNORE ROLLBACK or a create temporary table, by specifying TEMP as <OWNER> of the table to be created.']),
-8024: ('SQL', -8024, 'RESTORE CATALOG failed', ['Parts of the database catalog are deleted and then restored during certain '], ['Create a ']),
-8023: ('SQL', -8023, 'COSTLIMIT must be greater than COSTWARNING', ['A COSTLIMIT value was specified which was less than or equal to the specified COSTWARNING value. The COSTLIMIT value, however, must be greater than the COSTWARNING value.'], ['Use a <QUERY statement> issued on the system table DOMAIN.USERS to find out the COSTWARNING value for existing users.']),
-8022: ('SQL', -8022, 'User already connected', ['A user attempts to connect to the database system under a user name which was defined with EXCLUSIVE in a <CREATE USER>, <CREATE USERGROUP>, <ALTER USER>, or <ALTER USERGROUP statement>. Another user has connected using this name.'], ['Wait until the other user has disconnected using a <RELEASE statement>. ']),
-8021: ('SQL', -8021, 'Column must have DEFAULT specification', ['The attempt was made to specify the <action> SET DEFAULT as <DELETE RULE> in a REFERENTIAL CONSTRAINT DEFINITION, although no DEFAULT value had been defined for at least one section of the <REFERENCING COLUMN>.'], ['\240']),
-8020: ('SQL', -8020, 'Next volume required', [], []),
-8018: ('SQL', -8018, 'Index name must be unique', [], ['\240']),
-8017: ('SQL', -8017, 'Column must be group column', ['A column which is not a group column, i.e., which is not contained in the <GROUP CLAUSE>, was specified in a <SELECT COLUMN> or in the <HAVING CLAUSE>. Columns which are not group columns may only occur in arguments of the functions COUNT, SUM, AVG, MAX, MIN, STDDEV and VARIANCE.'], ['Insert the specified column into the <group clause> as a further group column or remove it from the <SELECT COLUMN> or <HAVING CLAUSE>.']),
-8016: ('SQL', -8016, 'Table must be a view table', ['In a <RENAME VIEW> or <DROP VIEW statement>, a table was specified which is not a view table.'], ['Specify a view table in the SQL statement or replace the SQL statement with a <RENAME TABLE > or <DROP TABLE statement>.']),
-8015: ('SQL', -8015, 'Table must be base table', ['The specification of a base table is expected. This specification is missing or the specified table is not a base table.'], ['Use a <QUERY statement> issued on the system table DOMAIN.TABLES to find out whether the specified table is a view table or result table. If it is a view table, use a <QUERY statement> issued on the system table DOMAIN.VIEWDEFS to find out the pertinent base table. The desired SQL statement can then be issued for the base table, if you have the corresponding privileges.']),
-8014: ('SQL', -8014, 'Result table must be FOR REUSE', ['A named result table which was not created with FOR REUSE was used in the <FROM clause> of a <QUERY statement> or SINGLE SELECT statement.'], ['Create the named result table with FOR REUSE and reissue the SQL statement.']),
-8013: ('SQL', -8013, 'Order column must be output column', [], ['\240']),
-8010: ('SQL', -8010, 'Table name must be in from list', ['A table name which was not listed in the <FROM clause> was specified in a <SELECT COLUMN>, <SEARCH CONDITION> or <ORDER CLAUSE>.'], ['\240']),
-8009: ('SQL', -8009, 'DEFAULT value must be in constraint specification', ['The specified DEFAULT value would violate the <CONSTRAINT DEFINITION>.'], ['\240']),
-8007: ('SQL', -8007, 'Column must be key column', ['The specification of a non-key column is not allowed here.'], ['Use a <QUERY statement> issued on the system table DOMAIN.COLUMNS to find out the columns which belong to the table key. Only these columns can be specified at this position within the SQL statement.']),
-8006: ('SQL', -8006, 'Data types must be compatible', ['Each data type can be compared to itself. Columns of data type CHAR with the different code attributes ASCII and EBCDIC can be compared to each other; they are implicitly adapted. Columns with the code attribute ASCII and EBCDIC can be compared to date, time and timestamp specifications. '], ['Use a QUERY statement issued on the system table DOMAIN.COLUMNS to find out the current definition of the affected columns. If need be, the attempt can be made to achieve comparability by applying a <CONVERSION function>.']),
-8005: ('SQL', -8005, 'Value expression must be parameter name', ['When calling a DB procedure, not a parameter but a constant value was specified for an OUT or IN/OUT parameter.'], ['Replace the specified constant with a parameter.']),
-8004: ('SQL', -8004, 'Constant must be compatible with column type and length', ['The specified constant does not match the data type for this column.'], ['Use a QUERY statement issued on the system table DOMAIN.COLUMNS to find out the definition of the affected column. Specify a constant with the correct data type.']),
-8003: ('SQL', -8003, 'The log and data area must be compatible', [], ['You can now warmstart the database.']),
-8002: ('SQL', -8002, 'User already connected', ['A user already connected to the database entered another <CONNECT statement>.'], ['If the user wants to continue working under another user name, he must specify first a <RELEASE statement> and then a <CONNECT statement>.']),
-8001: ('SQL', -8001, 'User must be connected', ['An database session can only be opened with a <CONNECT statement>.'], ['Specify a CONNECT statement.']),
-8000: ('SQL', -8000, 'Serverdb must be restarted', ['It is not possible to work on the serverdb because it was shut down.'], ['You can now warmstart the database.']),
-7900: ('SQL', -7900, 'Different block sizes', ['The block sizes specified for the restore and used for the backup differ from each other. The restore cannot be terminated successfully.'], ['The block size used for the corresponding save must also be used for the restore operation.']),
-7506: ('SQL', -7506, 'Parameter type not supported', ['In a '], ['Rewrite the C++ method so that it only contains parameters that are supported.']),
-7503: ('SQL', -7503, 'Constructor not found', ['The '], ['Correct the spelling of the database procedure name. ']),
-7501: ('SQL', -7501, 'ProgramaticId not found', ['The programatic ID specified in a CREATE PACKAGE statement could not be found in the registration database. '], ['Correct the spelling mistake or register the library.']),
-7500: ('SQL', -7500, 'DCOM HRESULT', ['An unexpected error occurred during the CREATE PACKAGE statement. The exact cause of the error is signified by a numerical value (HRESULT) in the error message.'], ['This type of error suggests that certain entries in the registration database are incorrect or missing. ']),
-7201: ('SQL', -7201, 'Long column is not open', '', ''),
-7200: ('SQL', -7200, 'Long column was opened READ ONLY', '', ''),
-7081: ('SQL', -7081, 'Hot Standby not configured', '', ''),
-7080: ('SQL', -7080, 'Query in statement not allowed', [], []),
-7079: ('SQL', -7079, 'A backup is already running', ['An attempt was made to start a backup while another backup is running. You can only run one backup at a time.'], ['No user action is possible.']),
-7078: ('SQL', -7078, 'No backup is running', ['An attempt was made to cancel a backup but no backup was running.'], ['No user action required.']),
-7077: ('SQL', -7077, 'Synonym not allowed', ['You have used an invalid synonym name within a CREATE TRIGGER or CREATE DBPROC statement.'], ['Instead of using the synonym name, use the full name for which the synonym was originally defined.']),
-7076: ('SQL', -7076, 'No more data to read from tape', ['You tried to restore a log backup from a no rewind tape. The given backup is older than the one required. There is no other backup on this tape.'], ['You no longer need the current tape. Insert the tape with the required backup and repeat the command.']),
-7075: ('SQL', -7075, 'Current SAVE SKIPPED, next is ready to take on this tape', ['You tried to restore a log backup from a no rewind tape. The given backup is older than the one required. It could still be saved on this tape.'], ['Try to carry out the RESTORE with the next backup on this tape.']),
-7074: ('SQL', -7074, 'Cycle in granted roles not allowed', ['The following reasons are possible:'], ['Check whether there is a typing error. If this is not so, check whether the roles which would result in the cycle can be combined to one role.']),
-7072: ('SQL', -7072, 'More than one column with default SERIAL not allowed', ['You tried to assign the DEFAULT SPEC DEFAULT SERIAL more than once when a base table was defined. No more than one column may exist in each base table with the <default spec> DEFAULT SERIAL.'], ['Decide on the column in which you want to leave out this definition. Then repeat the modified SQL statement.']),
-7071: ('SQL', -7071, 'AUTOSAVE LOG must be stopped', ['The attempt was made to perform a SHUTDOWN. This is not possible as long as the autosave is active.'], ['First stop Autosave and then perform the SHUTDOWN.']),
-7068: ('SQL', -7068, 'Outer join not allowed in this context', ['An <OUTER JOIN INDICATOR> was used in a <COMPARISON PREDICATE> in which no table column was specified in one of the two EXPRESSIONs. An <OUTER JOIN INDICATOR> is only allowed in a <JOIN PREDICATE>.'], ['You can repeat the SQL statement without the OUTER JOIN INDICATOR.']),
-7067: ('SQL', -7067, 'Update without repeated read not allowed', ['An optimistic lock was set to at least one table row by a previous SQL statement. Afterwards, another database user updated at least one of these rows. The database user who set the optimistic lock can make new changes to this row only after reading it with an (optimistic) lock.'], ['The row to be updated must be read again with an (optimistic) lock.']),
-7066: ('SQL', -7066, 'Unique index referenced by foreign key not allowed', ['The specified index cannot be deleted, because the columns contained in it were specified as referenced columns of the REFERENCED TABLE in a REFERENTIAL CONSTRAINT DEFINITION.'], ['The index can only be deleted after deleting the corresponding REFERENTIAL CONSTRAINT DEFINITION. Use a <QUERY statement> issued on the system table DOMAIN.COL_REFS_COL to find out which <CONSTRAINT definition>s are defined.']),
-7065: ('SQL', -7065, 'SUBTRANS COMMIT/ROLLBACK not allowed wthout SUBTRANS BEGI', ['The corresponding SQL statement SUBTRANS BEGIN must have been called for each subtransaction to be closed.'], ['Check the database application for the dynamic behavior of the <SUBTRANS statement>.']),
-7064: ('SQL', -7064, 'Feature not allowed in temp table definition', ['It is not possible to specify a REFERENTIAL CONSTRAINT DEFINITION for a temporary table.'], ['Repeat the SQL statement without the invalid specification, or create a permanent table instead of the temporary table.']),
-7063: ('SQL', -7063, 'Temp table not allowed', ['Only a subset of data definition statements is allowed for temporary tables; among them, the SQL statements for creating and deleting tables and for making the existence check.'], ['Decide whether the SQL data definition statement can be removed or whether a permanent table is to be created instead of the temporary table.']),
-7061: ('SQL', -7061, 'LOCK ROW for this table not allowed', ['A <LOCK statement> with <ROW LOCK SPEC> specification can only be performed for an updateable join view table. But not even updateable join view tables allow a <ROW LOCK SPEC> with OPTIMISTIC specification.'], ['The effect can be achieved by several <ROW LOCK SPEC> specifications issued on the underlying base tables.']),
-7060: ('SQL', -7060, 'Remote TABLE LOAD/UNLOAD not allowed', ['DATALOAD with NOLOG option or UNLOAD cannot be performed for a table stored on a serverdb other than that to which you are connected.'], ['The SQL statement can be repeated if the NOLOG option is not specified or if you connect to the serverdb where the table is stored.']),
-7058: ('SQL', -7058, 'Correlated subquery with select in from clause not allowe', ['A <QUERY EXPRESSION> specification in the <FROM clause> of a correlated subquery is not allowed.'], ['Formulate the corresponding subquery to leave out the QUERY EXPRESSION. If this is not possible, split the SQL statement into at least two SQL statements and generate a named result table that can be used in the <FROM clause>.']),
-7057: ('SQL', -7057, 'View definition contradicts new table definition', [], ['\240']),
-7056: ('SQL', -7056, 'Subquery not allowed', ['A <SUBQUERY> specification in a <CONSTRAINT DEFINITION> is not allowed.'], ['\240']),
-7055: ('SQL', -7055, 'Column(s) already indexed', ['There is already an index for the specified column(s).'], ['Use a <QUERY statement> issued on the system table DOMAIN.IND_USES_COL to check whether the index values are stored in ascending or descending order. No user action is required.']),
-7051: ('SQL', -7051, 'Read only view WITH CHECK OPTION not allowed', ['The view table to be created is not updateable. The specification WITH CHECK OPTION is not allowed for non-updateable view tables.'], ['Repeat the SQL statement without the WITH CHECK OPTION.']),
-7050: ('SQL', -7050, 'Fastload with indexed table not allowed', ['An index is on the table to be loaded. In this case, a fast load is not possible.'], ['Delete the index or do without fast loading.']),
-7048: ('SQL', -7048, 'DROP/ALTER USER not allowed while user is connected', ['The attempt was made to drop a user or to alter the characteristics of a user who was connected. This is only permitted for a user who is not connected.'], ['Repeat the SQL statement when the user to be dropped or altered is not connected.']),
-7046: ('SQL', -7046, 'Column with length greater than 254 not allowed', ['The attempt was made to use a CHAR-type column with a length greater than 254 in a statement part that does not allow for such a column. This could have happened, for example, if the attempt was made to change a column with a defined length less than 254 into a column with a defined length greater than 254.'], ['Do not use this column in the statement part. Try to achieve the desired effect by application programming. For a change in the defined length, the desired effect could be achieved by replacing the <ALTER definition> with a <MODIFY definition>. However, this is likely to take substantially longer depending on the data records in the accessed table and the indexes defined for it.']),
-7045: ('SQL', -7045, 'Parameter spec not allowed', ['A parameter was specified, although this database component or this kind of application programming only allows the use of constants.'], ['Replace the parameter with a constant.']),
-7043: ('SQL', -7043, 'Group member not allowed', ['The following reasons are possible: '], ['A database administrator can use a <QUERY statement> issued on the system table DOMAIN.USERS to find out the usergroup to which the respective user belongs. Other users only see the users and usergroups which belong to the same database administrator as they do.']),
-7042: ('SQL', -7042, 'Key update not allowed', ['The attempt was made to change the value of a key column in a temporary table to a new value. This is not allowed. Key columns can only be changed in permanent tables.'], ['If another key value is wanted, delete the row with the old key value and insert a row with the new key value.']),
-7041: ('SQL', -7041, 'Result table name not allowed', ['In the CREATE VIEW statement a named result table was specified in a FROM condition of the QUERY EXPRESSION. But only base or view tables may be specified.'], ['Specify a base or view table in the SQL statement and expand the SEARCH CONDITION to include conditions used when generating the result table.']),
-7040: ('SQL', -7040, 'Referential constraint not allowed', ['There is already a REFERENTIAL CONSTRAINT DEFINITION with the specified referencing table. Moreover, CASCADE dependency arises. Under these conditions, all <CONSTRAINT definition>s with the indicated referencing table must specify either CASCADE or RESTRICT.'], ['Rethink the desired effect, because it would result in basically contesting situations. The user may see information about the existing REFERENTIAL CONSTRAINT DEFINITIONs using a <QUERY statement> issued on the system table DOMAIN.COL_REFS_COL.']),
-7039: ('SQL', -7039, 'Cycle in referential constraint definition invalid', ['An attempt has been made to generate a CONSTRAINT definition (REFERENTIAL CONSTRAINT DEFINITION) which would produce an invalid reference cycle. This CONSTRAINT definition would lead to discrepancies so the database system has rejected it.'], ['Delete the cycle dependencies.']),
-7038: ('SQL', -7038, 'Foreign key column not allowed', ['A foreign key column is a column which was specified in the <REFERENCING COLUMN> of a <REFERENTIAL CONSTRAINT DEFINITION>.'], ['Delete the REFERENTIAL CONSTRAINT DEFINITION and then the column or key.']),
-7037: ('SQL', -7037, 'NULL value for NOT NULL column not allowed', ['The error message is returned for a <REFERENTIAL CONSTRAINT DEFINITION> with ON DELETE SET NULL specification, if a REFERENCING COLUMN does not allow the NULL value.'], ['Choose another <ACTION> in the <DELETE RULE> or admit the NULL value for the corresponding column(s) in the referencing table.']),
-7036: ('SQL', -7036, 'ROWNO specification not allowed in this context', ['One of the following conditions was violated: '], ['\240']),
-7035: ('SQL', -7035, 'DEFAULT specification allowed for this column', ['An <INSERT> or <UPDATE statement> or a <DEFAULT PREDICATE> was issued with a DEFAULT specification for a column for which no <DEFAULT SPEC> had been defined in the <CREATE TABLE> or any subsequent <ALTER TABLE statement>.'], ['Specify the desired value instead of DEFAULT.']),
-7032: ('SQL', -7032, 'SQL statement not allowed for column of data type LONG', ['The command cannot be applied to LONG columns.'], ['Use one of the operations allowed for the data type LONG (see Reference manual).']),
-7029: ('SQL', -7029, 'Function not allowed for this data type', [], ['\240']),
-7026: ('SQL', -7026, 'SQL Sstatement not allowed without previous FETCH', ['The attempt was made to issue an SQL statement with CURRENT OF for the table (<RESULT TABLE NAME>) without having previously issued a successful <FETCH statement> on the specified result table.'], ['Issue a FETCH statement for this result table and repeat the SQL statement.']),
-7024: ('SQL', -7024, 'Alter column not allowed, constraint violation', ['The attempt was made to redefine a <constraint definition> for a particular column. The SQL statement fails when the table contains rows which do not meet the <CONSTRAINT definition>.'], ['\240']),
-7023: ('SQL', -7023, 'Dropping of all columns', ['You have attempted to drop all the columns in a table. This is not allowed.'], ['Delete the table using the DROP TABLE statement. The DROP TABLE statement deletes all view tables, privileges, indexes, CONSTRAINT definitions (REFERENTIAL CONSTRAINT DEFINITION), etc. which depend on this table. ']),
-7022: ('SQL', -7022, 'Columns from more than one table not allowed', ['In certain cases, columns from more than one table may not be addressed within an <EXPRESSION>.'], ['Consider whether issuing other SQL statements could give the desired result.']),
-7021: ('SQL', -7021, 'View column derived from function not allowed', ['A view table column was specified which was the result of an arithmetic expression or of a set function. In the present case, it is not allowed to specify such a column.'], ['To achieve the desired effect try one or more other SQL statements.']),
-7019: ('SQL', -7019, 'Feature not allowed in view definition', ['ROWNO specifications are not allowed in a view definition.'], ['Remove the ROWNO specification from the SQL statement.']),
-7018: ('SQL', -7018, 'Variable not allowed in view definition', ['Parameters must not be specified in the <CREATE VIEW statement>.'], ['Use constants instead of variables.']),
-7017: ('SQL', -7017, 'User not allowed', [], ['Correct the user name.']),
-7016: ('SQL', -7016, 'Parameter spec not allowed in this context', [], ['\240']),
-7015: ('SQL', -7015, 'More than one update row not allowed', [], ['\240']),
-7012: ('SQL', -7012, 'More than one update row not allowed', ['The attempt was made to modify several rows with an <UPDATE statement>, specifying a new value for a LONG column. This is not allowed.'], ['Modify the <UPDATE statement> in such a way that only one row is updated, or do without the value modification for the LONG column.']),
-7011: ('SQL', -7011, 'Correlated subquery not allowed', ['A correlated subquery was used in a <QUERY EXPRESSION> containing at least a UNION, INTERSECT, or EXCEPT. This is not yet allowed.'], ['The desired effect can be achieved by splitting the <QUERY statement> into several SQL statements.']),
-7009: ('SQL', -7009, 'NULL value in key column not allowed', ['Key columns must not be set to the NULL value.'], ['Use non-NULL values for key columns.']),
-7008: ('SQL', -7008, 'Updates of this table not allowed', ['The specified table cannot be updated for the following possible reasons: '], ['\240']),
-7007: ('SQL', -7007, 'Key column not allowed', ['A key column specification is not allowed here.'], ['Remove the key column specification from the SQL statement.']),
-7006: ('SQL', -7006, 'Reserved identifier not allowed', ['In the current SQLMODE, the specified name is a reserved keyword and must not be used to identify database objects.'], ['Correct the SQL statement using another <identifier>.']),
-7005: ('SQL', -7005, 'Lower bound greater than upper bound not allowed', ['In the case of an upper and lower limit specification for a range of values, the lower limit is greater than the upper limit.'], ['Correct the values for the upper and lower limit in the SQL statement.']),
-7004: ('SQL', -7004, 'DEFAULT not allowed', [], ['\240']),
-7003: ('SQL', -7003, 'NOT NULL not allowed', ['Columns with NOT NULL specification cannot be added to a table with the <ALTER TABLE statement>.'], ['Repeat the SQL statement after removing the specification NOT NULL.']),
-7002: ('SQL', -7002, 'KEY not allowed', [], ['Specify the key columns in the SQL statement correctly.']),
-6016: ('SQL', -6016, 'Duplicate format code', [], ['\240']),
-6014: ('SQL', -6014, 'Duplicate value', [], ['\240']),
-6013: ('SQL', -6013, 'Duplicate trigger definition', ['There is already a trigger with the specified name.'], ['Use a <QUERY statement> issued on the system table DOMAIN.TRIGGERS to find out the trigger names already used. Use another name. ']),
-6012: ('SQL', -6012, 'Duplicate default', ['There is already a default specification for the specified column.'], ['Do without a default specification, or attempt to obtain the desired effect by changing the existing default. Use a <QUERY statement> issued on the system table DOMAIN.COLUMNS to find out the definition of the existing default.']),
-6011: ('SQL', -6011, 'Duplicate constraint', ['There is already a <CONSTRAINT DEFINITION> for the specified column.'], ['Do without a <CONSTRAINT DEFINITION> specification, or attempt to obtain the desired effect by changing the existing <CONSTRAINT definition>. Use a QUERY statement issued on the system table DOMAIN.CONSTRAINTS to check the existing CONSTRAINT definitions.']),
-6009: ('SQL', -6009, 'Duplicate reference name', ['A reference name was selected twice in the FROM clause of a QUERY SPEC. This violates the requirement that each table must have a unique reference name.'], ['Change one of the reference names.']),
-6008: ('SQL', -6008, 'Duplicate index name', ['There is already an index with the specified name.'], ['Use another name for the index or delete the existing one.']),
-6006: ('SQL', -6006, 'Duplicate name', ['There is already a data object with the specified name.'], ['Repeat the SQL statement with another name.']),
-6003: ('SQL', -6003, 'Duplicate result table name', ['The SQLMODEs ANSI and DB2 require that a result table generated by DECLARE CURSOR is closed using a <CLOSE statement>, before the result table name can be used to open a new result table within the same transaction.'], ['Insert a CLOSE statement into the application.']),
-6002: ('SQL', -6002, 'Duplicate privilege', ['A privilege to be granted was listed twice in the SQL statement.'], ['Remove one of these privileges from the SQL statement.']),
-6001: ('SQL', -6001, 'Duplicate column name', [], ['\240']),
-6000: ('SQL', -6000, 'Duplicate table name', ['There is already a table with the specified name.'], ['Choose another name for the new table.']),
-5016: ('SQL', -5016, 'Missing delimiter', ['The SQL statement contains an incorrect delimiter, or a delimiter is missing.'], ['Correct the SQL statement according to the syntax description and the current SQLMODE by using one of the specified delimiters.']),
-5015: ('SQL', -5015, 'Missing keyword', ['The SQL statement contains a keyword that is incorrect or that is not known in the current SQLMODE; or a keyword is missing.'], ['Correct the SQL statement according to the syntax description and the current SQLMODE by using one of the specified keywords.']),
-5014: ('SQL', -5014, 'Missing definite column name', ['The number of tables specified in a <FROM clause> of the SQL statement is greater than 1. A <COLUMN NAME> without preceding <TABLE SPEC> was used, and this <COLUMN NAME> occurs in more than one of the tables specified in the <FROM clause>.'], ['To ensure that the COLUMN NAME is unique, place the desired <TABLE SPEC> in front of it.']),
-5013: ('SQL', -5013, 'Missing update column', ['The attempt was made to update at least one column value of an updateable join view table column using an <UPDATE statement>. This column value can only be updated together with other column values. At least one of the required column values is missing in the <UPDATE statement>.'], ['Insert the missing column values into the <UPDATE statement> or execute <UPDATE statement>s for the underlying table(s) of the updateable join view table.']),
-5012: ('SQL', -5012, 'Missing definite table name', ['If a table name in a <FROM clause> is used several times with different <OWNER>s, then the table name must always be specified with the desired <OWNER> within this SQL statement.'], ['Specify the OWNER with the table names.']),
-5010: ('SQL', -5010, 'Missing value specification', ['A value is missing, or the specified value is not allowed.'], ['Correct the value specified in the SQL statement, or insert a value into the SQL statement.']),
-5009: ('SQL', -5009, 'Missing integer', ['An integer is missing.'], ['Insert an integer into the SQL statement.']),
-5008: ('SQL', -5008, 'Missing string constant', ['A string constant is missing in the issued SQL statement.'], ['Insert a <STRING LITERAL> into the SQL statement.']),
-5007: ('SQL', -5007, 'Missing numeric constant', ['A number is missing.'], ['The error position indicates the location of the missing number. Insert a number into the SQL statement.']),
-5006: ('SQL', -5006, 'Missing identifier', ['An <identifier> is missing.'], ['The error position indicates the location of the missing <IDENTIFIER>. Insert an <identifier> into the SQL statement.']),
-5005: ('SQL', -5005, 'Missing non-NULL value', ['The <INSERT> or <UPDATE statement> must contain non-NULL values for all mandatory columns. If <KEY SPEC> is specified, non-NULL values must be specified for all key columns.'], ["Use a QUERY statement issued on the system table DOMAIN.COLUMNS to find out the table's mandatory and key columns."]),
-5004: ('SQL', -5004, 'Missing constant', ['A constant is missing in the SQL statement.'], ['Insert a constant into the SQL statement.']),
-5003: ('SQL', -5003, 'Missing key specification', ['The SQL statement requires a primary key specification. The primary key was omitted or is incomplete.'], ['Use a QUERY statement issued on the system table DOMAIN.COLUMNS to find out the key columns of the table. Correct the key specified in the SQL statement, or insert a key specification into the SQL statement.']),
-5002: ('SQL', -5002, 'Missing exclusive lock', '', ''),
-5001: ('SQL', -5001, 'Missing privilege', [], ['Use a <QUERY statement> issued on the system table DOMAIN.USR_USES_COL to find out the privileges you have for the specified table or its columns. You cannot execute the desired SQL statement.']),
-4027: ('SQL', -4027, 'Unknown session', ['You want to switch on the '], ['Correct the session number.']),
-4025: ('SQL', -4025, 'Unknown or not loaded character set', ['The specified CHARACTER SET is unknown.'], ['Check the spelling of the character set. Use a <QUERY statement> issued on the system table DOMAIN.CHARSET to find out whether the specified character set has been loaded. Replace the specification by one of the loaded character sets or ensure that the character set needed will be loaded.']),
-4024: ('SQL', -4024, 'Unknown name', ['There is no database object with the specified name.'], ['Use <QUERY statement>s issued on system tables to find out which objects you are authorized to see.']),
-4023: ('SQL', -4023, 'Unknown function name', [], ['Replace the NAMED QUERY EXPRESSION with a QUERY EXPRESSION. If the error message occurs although there is no <NAMED QUERY EXPRESSION> in the SQL statement, check whether the specified function is only not offered in the SQLMODE being used. ']),
-4020: ('SQL', -4020, 'Unknown sequence name', ['There is no sequence with the specified name.'], ['Use a <QUERY statement> issued on the system table DOMAIN.SEQUENCES to see a list of the existing sequences.']),
-4019: ('SQL', -4019, 'Unknown trigger name', ['There is no trigger with the specified name.'], ['Use a <QUERY statement> issued on the system table DOMAIN.TRIGGERS to find out the trigger names already used.']),
-4018: ('SQL', -4018, 'Unknown default', ['There is no default specified for a given column.'], ['Add a default value.']),
-4017: ('SQL', -4017, 'Unknown constraint', ['There is no <CONSTRAINT DEFINITION> for the specified column.'], ['No user action is necessary.']),
-4016: ('SQL', -4016, 'Unknown procedure name', ['There is no DB procedure with the specified name.'], ['Use a <QUERY statement> issued on the system table DOMAIN.DBPROCEDURES to see a list of the existing DB procedures. Change the procedure name in the SQL statement accordingly.']),
-4014: ('SQL', -4014, 'Unknown SERVERDB name', ['There is no serverdb with the specified name.'], ['Use a <QUERY statement> issued on the system table DOMAIN.SERVERDBS to see a list of the existing serverdb names. Change the name of the serverdb in the SQL statement accordingly.']),
-4013: ('SQL', -4013, 'Unknown usergroup name', ['There is no usergroup with the specified name.'], ['Use a <QUERY statement> issued on the system table DOMAIN.USERS to see a list of the existing usergroup names. Change the usergroup name in the SQL statement accordingly.']),
-4012: ('SQL', -4012, 'Unknown parseid', '', ''),
-4011: ('SQL', -4011, 'Unknown index name', ['There is no named index with the specified name for the table being used.'], ['Use a <QUERY statement> issued on the system table DOMAIN.IND_USES_COL to find out the existing indexes. Change the index name in the SQL statement accordingly.']),
-4010: ('SQL', -4010, 'Unknown MAPCHAR SET name', ['There is no MAPCHAR\240SET with the specified name.'], ['Use a <QUERY statement> issued on the system table DOMAIN.MAPCHARSETS to see a list of the available MAPCHAR SETs. Change the name in the SQL statement accordingly.']),
-4009: ('SQL', -4009, 'Unknown referential constraint name', ['There is no <REFERENTIAL CONSTRAINT DEFINITION> with the specified name.'], ['Use a <QUERY statement> issued on the system table DOMAIN.COL_REFS_COL to find out which <CONSTRAINT definition>s are defined. Change the <REFERENTIAL CONSTRAINT NAME> in the SQL statement accordingly.']),
-4008: ('SQL', -4008, 'Unknown user name/password combination', ['The specified combination of user name and password is unknown. The database system can only be accessed by a combination that is known to the database.'], ['Change the user or password specification in the SQL statement.']),
-4007: ('SQL', -4007, 'Unknown synonym name', ['There is no synonym with the specified name.'], ['Use a <QUERY statement> issued on the system table DOMAIN.SYN_REFS_TAB to see a list of the existing synonym names. Change the name of the domain in the SQL statement accordingly.']),
-4006: ('SQL', -4006, 'Unknown domain name', ['There is no domain with the specified name.'], ['Use a <QUERY statement> issued on the system table DOMAIN.DOMAINS to see a list of the known domains. Change the name of the domain in the SQL statement accordingly. It may be sufficient to place the missing <OWNER> in front of the statement. ']),
-4005: ('SQL', -4005, 'Unknown column name', ['There is no column with the specified name in any of the specified tables.'], ['Use <QUERY statement>s issued on the system table DOMAIN.COLUMNS to find out the names of the columns existing in the tables. Correct the user name.']),
-4004: ('SQL', -4004, 'Unknown table name', ['A table with the specified name is not known to you. This table may not exist; or this table exists but you have no privileges for it.'], ['Use a <QUERY statement> issued on the system table DOMAIN.TABLES to find out the names of the tables for which you have privileges. Then correct the table name. It may be sufficient to place the missing <OWNER> in front of it. If this does not remove the error, create a table with the desired name or check why you have no privileges for the existing table.']),
-4003: ('SQL', -4003, 'Unknown user name', ['There is no user with this name.'], ['A DBA or the SYSDBA can use a <QUERY statement> issued on the system table DOMAIN.USERS to find out the known user names. Other users can use a <QUERY statement> issued on the system table DOMAIN.USERS to find out the users which belong to the same DBA as they do. Repeat the SQL statement with a known user name.']),
-4002: ('SQL', -4002, 'Unknown password', ['The specified password is unknown.'], ['Repeat the ALTER PASSWORD statement using the correct password.']),
-4000: ('SQL', -4000, 'Unknown result table', ['There is no result table (any more) with the specified name.'], ['Use a <QUERY statement> issued on the system table DOMAIN.TABLES to find out the names of the existing result tables. Correct the name of the result table or check why the result table with the specified name was deleted already. ']),
-3999: ('SQL', -3999, 'Invalid parameter', [], ['\240']),
-3998: ('SQL', -3998, 'Wrong password', ['You want to activate a '], ['Correct the password.']),
-3995: ('SQL', -3995, 'Invalid pattern', ['The value specified in a <LIKE PREDICATE> does not comply with the syntax of <LIKE expression>s.'], ['The value must be corrected according to the syntax rules of a <LIKE EXPRESSION> in a <LIKE PREDICATE>.']),
-3993: ('SQL', -3993, 'Invalid long column destpos', '', ''),
-3990: ('SQL', -3990, 'Invalid long column startpos', '', ''),
-3989: ('SQL', -3989, 'Invalid long column length', '', ''),
-3988: ('SQL', -3988, 'Invalid long column position', '', ''),
-3103: ('SQL', -3103, 'Invalid sequence definition', ['The following reasons are possible:'], []),
-3102: ('SQL', -3102, 'Invalid subtrans structure', ['In a DB procedure, more or less subtransactions were dynamically opened than closed. The subtransactions opened but not closed until the end of the DB procedure were rolled back.'], ['Check which error in the DB procedure generated such nesting of subtransactions. Correct the database procedure accordingly.']),
-3068: ('SQL', -3068, 'Mismatch of parameter configuration between backup and instance', '', ''),
-3067: ('SQL', -3067, 'Invalid timezone', ['An invalid value for timezone was specified in the function NEW_TIME.'], ['Repeat the SQL statement with a correct timezone.']),
-3066: ('SQL', -3066, 'Date input value inconsistent', ['Data from two format elements was converted. The values of the data are contradictory. Perhaps a Julian calendar day was specified which does not lie within the specified year or month, or denotes another day of the month, or the seconds of the day were specified but do not correspond to the specified hours or minutes or seconds of the minute.'], ['\240']),
-3065: ('SQL', -3065, 'Invalid date input value', ['The value to be converted into a date value contains an invalid element, or too many or too few elements.'], ['Correct the value according to the format.']),
-3064: ('SQL', -3064, 'Date input value out of range', ['An invalid value was specified for a format element in a function that converts a value into a date value. '], ['Correct the value.']),
-3063: ('SQL', -3063, 'Invalid format code', ['The format specification in a function for date or number conversion contains an invalid format code.'], ['Remove the invalid format code.']),
-3062: ('SQL', -3062, 'Invalid month', ['For a date specification, an invalid month was specified in the chosen language or format. '], ['Check the chosen language and format and repeat the SQL statement with the correct day of the week. ']),
-3061: ('SQL', -3061, 'Invalid escape value', ['Exactly one character is valid for an escape value.'], ['Reduce the escape value to one character.']),
-3060: ('SQL', -3060, 'Invalid escape sequence', ['The escape character may only be placed before a <MATCH CHAR> which is identical to the escape character, before a <MATCH STRING>, or before a <MATCH SET> which is not a <MATCH CHAR>.'], ['Remove the surplus escape character.']),
-3059: ('SQL', -3059, 'Invalid day of week', ['For a date specification, an invalid day of the week was specified in the chosen language or format. '], ['Check the chosen language and format and repeat the SQL statement with the correct day of the week. ']),
-3054: ('SQL', -3054, 'Invalid block size', [], []),
-3051: ('SQL', -3051, 'Invalid cachelimit value', '', ''),
-3050: ('SQL', -3050, 'Invalid timestamp format', ['The specified value is not a valid timestamp value or does not correspond to the date and time format chosen during installation or the current session.'], ['Correct the timestamp value.']),
-3049: ('SQL', -3049, 'Invalid time format', ['The specified value is not a valid time value or does not correspond to the date and time format chosen during installation or the current session.'], ['Correct the time value.']),
-3048: ('SQL', -3048, 'Invalid date format', ['The specified value is not a valid date value or does not correspond to the date and time format chosen during installation or the current session.'], ['Correct the date value.']),
-3047: ('SQL', -3047, 'Invalid table for RESTORE CATALOG', [], []),
-3046: ('SQL', -3046, 'Invalid char position in string function', ['An invalid value was specified for a position in a <STRING FUNCTION>.'], ['In the SQL statement, a value must be specified for a position which is greater than 0 and less than or equal to the defined column width.']),
-3041: ('SQL', -3041, 'Invalid position', '', ''),
-3038: ('SQL', -3038, 'Invalid volume size', ['The value for the size of a volume specified during installation is not a valid number.'], ['Specify a valid number.']),
-3037: ('SQL', -3037, 'Invalid volume name', ['The volume name specified during installation is invalid. This name depends on the environment in which the database system is running. Usually, it is an operating system file name.'], ['The error message contains the incorrect volume name. Ensure that the name meets the conventions laid out for the environment in which the database system is running.']),
-3035: ('SQL', -3035, 'Invalid date time format', ['The DATE_TIME_FORMAT specified during installation is invalid.'], ['Specify EUR, INTERNAL, ISO, JIS or USA for the date and time format.']),
-3030: ('SQL', -3030, 'Invalid SESSION TIMEOUT', [], ['If a user-specific TIMEOUT value was defined in the <CREATE USER> or <CREATE USERGROUP statement>, this is the maximum value.']),
-3024: ('SQL', -3024, 'Invalid numeric expression', ['It was intended to perform a division by 0. '], ['Check whether this error can be prevented by suitable specifications (PREDICATEs).']),
-3022: ('SQL', -3022, 'Invalid number of tables for outer join', ['If an <OUTER JOIN INDICATOR> was specified in at least one <JOIN PREDICATE> of the <QUERY SPEC>, the number of the underlying tables of the <QUERY SPEC> <FROM clause> must be precisely two or the following must apply:'], ['The attempt should be made to add any missing OUTER JOIN indicators or to split the SQL statement into several SQL statements, or to achieve the desired effect by <QUERY EXPRESSION>s in the <FROM clause>.']),
-3021: ('SQL', -3021, 'Invalid mixture of functions and columns', [], ['Correct the SQL statement. ']),
-3020: ('SQL', -3020, 'Invalid length for this data type', ['The specified length is not permitted for the data type.'], []),
-3019: ('SQL', -3019, 'Invalid exponent', ['The following reasons are possible: '], ['\240']),
-3018: ('SQL', -3018, 'Invalid numeric parameter', ['The specified value is not a valid number.'], ['Check the numeric value entered as parameter.']),
-3017: ('SQL', -3017, 'Invalid unsigned integer', ['No valid number was specified.'], ['Correct the SQL statement.']),
-3016: ('SQL', -3016, 'Invalid numeric constant', [], ['\240']),
-3014: ('SQL', -3014, 'Invalid end of SQL statement', ['According to the syntax, the specified SQL statement is not allowed in the SQLMODE which is currently valid.'], ['The error position shows the location where the specified SQL statement deviates from the permitted syntax.']),
-3011: ('SQL', -3011, 'Invalid column name', ['The specified column name does not comply with the syntax for <identifier>s.'], ['Correct the column name specified in the SQL statement.']),
-3010: ('SQL', -3010, 'Invalid character value', ['When defining a terminal character set, you tried to perform a conversion for a digit, a letter of the 26-character alphabet or a special character (comma, colon, etc.). This is neither allowed nor necessary.'], ['Do not do this.']),
-3009: ('SQL', -3009, 'Invalid table name', ['The specified table name does not comply with the syntax for <identifier>s.'], ['Correct the table name specified in the SQL statement.']),
-3008: ('SQL', -3008, 'Invalid keyword or missing delimiter', ['The SQL statement contains an incorrect keyword, or a keyword unknown in the currently valid SQLMODE, or a keyword or delimiter is missing.'], ['Correct the SQL statement according to the syntax description and the current SQLMODE.']),
-3007: ('SQL', -3007, 'Invalid sequence for DML and DDL statements', ['Modifications were made to the catalog in the time between a <QUERY statement> which does not generate a result table and the corresponding <FETCH statement>s. These modifications concerned the underlying table of the <QUERY statement>.'], ['Repeat the QUERY and FETCH statement.']),
-3005: ('SQL', -3005, 'Invalid SQL statement', ['The SQL statement either contains a typing error within the first two keywords, is unknown in the current SQLMODE or is not permitted in the current database version.'], ['Correct the typing errors, or specify another SQL statement.']),
-3004: ('SQL', -3004, 'Invalid host file sequence', ['The host file or backup device specified in multi-volume processing to continue the restore function does not contain any items relating to the command executed up to then.'], ['The error message contains an additional error description which must be interpreted according to the operating system being used. ']),
-3003: ('SQL', -3003, 'Invalid user name', ['The specified user name does not comply with the syntax for the user <IDENTIFIER>.'], ['Correct the user name specified in the SQL statement.']),
-3002: ('SQL', -3002, 'Invalid data type', ['The specified data type is unknown in the current SQLMODE.'], ['Use the valid data types described in the chapter <COLUMN DEFINITION> of the Reference manual.']),
-3000: ('SQL', -3000, 'Invalid host file content', ['The host file or backup device has no contents that correspond to the command.'], ['Specify the host file or backup device that matches the menu function. In multi-volume processing, all versions loaded by then must be reloaded.']),
-2029: ('SQL', -2029, '<sequence name>.CURRVAL is not yet defined in this sessio', ['You attempted to execute <sequence name>.CURRVAL before using <sequence name>.NEXTVAL in the current session.'], ['Execute <sequence name>.NEXTVAL before executing <sequence name>.CURRVAL.']),
-2028: ('SQL', -2028, 'Sequence <sequence name> exhausted', ['You tried to find out the next value of the specified sequence with <sequence name>.NEXTVAL. This is impossible for one of the following reasons:'], ['\240']),
-2027: ('SQL', -2027, 'Space for converted value too small', ['You tried to convert data in ASCII or UCS-2 format (see also '], ['Check whether the target column has been defined enough space. If you cannot increase the target column, you cannot carry out an explicit conversion. You can try to avoid this error by explicitly converting the data used, for example, for comparisons.']),
-2025: ('SQL', -2025, 'Invalid number of backup devices', ['The number of backup devices specified for a save or restore operation does not correspond to the installation parameter MAXBACKUPDEVS.'], ['Use the database administration tool to check the parameter and modify it, if necessary.']),
-2020: ('SQL', -2020, 'Data buffer too small', ['There is no free data buffer space available at the time. The execution of the SQL statement was cancelled. The database system implicitly performs a SHUTDOWN.'], ['Perform a RESTART of the database with an expanded data buffer (installation parameter DATA_CACHE).']),
-2014: ('SQL', -2014, 'Identifier too long', ['The specified identifier is too long for the SQLMODE used.'], ['Pay attention to the restrictions in the table when specifying the identifier.']),
-2013: ('SQL', -2013, 'Select column list too long', ['The following reasons are possible:'], ['\240']),
-2012: ('SQL', -2012, 'View column list too long', ['In a <CREATE VIEW statement>, the number of view table columns to be defined must be equal to the number of columns issued as the <QUERY EXPRESSION> result. In the present case, the attempt was made to create more view table columns than columns are available in the <QUERY request> result.'], ['Reduce the number of view table columns specified in the SQL statement.']),
-2010: ('SQL', -2010, 'Assignment impossible, char value too long', ['In an <INSERT statement> with a <QUERY EXPRESSION> or in an <UPDATE statement>, the attempt was made to assign a character string to a column of data type CHAR. This character string was too long. The error message is returned for the first occurring value of excess length, not while analyzing the maximum column lengths.'], ['Use ']),
-2009: ('SQL', -2009, 'Join columns too long', ["The internal length of a table's join columns must not exceed 250 characters. Join columns are the columns that are contained in a <JOIN PREDICATE>. "], ['You can attempt to achieve the expected result by issuing several <QUERY statement>s and creating tables as temporary results.']),
-2008: ('SQL', -2008, 'Volume size too small', [], ['\240']),
-2004: ('SQL', -2004, 'Numeric constant too long', [], ['The number which was incorrectly entered may be determined from the position specification in the error message. ']),
-2003: ('SQL', -2003, 'Output columns too long', ['The following reasons are possible:'], ['\240']),
-2002: ('SQL', -2002, 'One output column too long', ['The concatenation of values resulted in an excessively long alphanumeric value.'], ['Do without this kind of output. If it can be assumed that all values in a column are shorter than the maximum length defined for this column, the attempt can be made to reduce the result to less characters by applying the SUBSTR function. In any case, the columns and expressions involved in a concatenation can be output separately.']),
-2001: ('SQL', -2001, 'Key too long', [], ['\240']),
-2000: ('SQL', -2000, 'Row too long', ['When (re-)defining a table, the length of a table row exceeds 8088 bytes.'], ['\240']),
-1755: ('SQL', -1755, 'SQL statement will drop further objects (use CASCADE)', ['A DROP USER, DROP TABLE, DROP VIEW or REVOKE statement was specified for which the CASCADE option had not been specified implicitly or explicitly. Other objects depend on the object to be deleted. These objects must be deleted as well but this is only possible with an implicit or explicit specification of the CASCADE option.'], ['Before specifying the same SQL statement with the CASCADE option, you should check which dependent objects exist.']),
-1556: ('SQL', -1556, 'Data space full', ['The '], ["You must increase the database's data area by adding extra "]),
-1452: ('SQL', -1452, 'Duplicate secondary key', ['Several table rows already exist with the same values in the specified columns when a UNIQUE definition is specified, when the COLUMN ATTRIBUTE UNIQUE is used or when a UNIQUE definition is specified in the CREATE INDEX statement.'], ['Do not use the UNIQUE definition; otherwise ensure that only one table row contains a certain combination of values in the specified columns. The error message specifies the column or multiple-column index already containing the specified values.']),
-1406: ('SQL', -1406, 'Output value truncated', ["The column's range of values is greater than that of the SQL variable. The value was truncated when being inserted into the SQL variable."], ['Adapt the range of values of the SQL variable to that of the column.']),
-1405: ('SQL', -1405, 'Missing indicator variable', '', ''),
-1403: ('SQL', -1403, 'Row not found', ['There is no (further) table row which meets the specified criteria.'], ['No user action is required.']),
-1402: ('SQL', -1402, 'Integrity violation', ['Insertions or updates would violate integrity constraints specified in the definition of the base or view table.'], ['The error message specifies the column which would violate the integrity constraints. Correct the input value for the corresponding column.']),
-1400: ('SQL', -1400, 'Input parameter cannot be NULL value', ['The value of an input parameter must not be a null value, because null values are not permitted for the column.'], ['Modify the program or change the column definition in the CREATE TABLE statement.']),
-1201: ('SQL', -1201, 'Too few columns', ['In a REFERENTIAL CONSTRAINT DEFINITION fewer REFERENCING COLUMNS than REFERENCED COLUMNS were specified. The number of specified columns in the referencing table must correspond to the number of referenced columns of the REFERENCED TABLE specified implicitly or explicitly.'], ['Use a QUERY statement issued on the system table DOMAIN.COLUMNS to find out the current definition of the key columns in the referenced table. Use a QUERY statement issued on the system table DOMAIN.IND_USES_COL to find out the indexes of the referenced table. The specification of the referencing table columns must be adapted accordingly.']),
-1200: ('SQL', -1200, 'Too few values', ['In an INSERT or UPDATE statement the number of specified values is less than the number of column names which may have been implicitly specified.'], ['Match the number of specified values in the SQL statement to the number of specified column names. Use a QUERY statement issued on the system table DOMAIN.COLUMNS for an INSERT statement without column name specification to determine the definition of the table used.']),
-1120: ('SQL', -1120, 'Too many statements in definition', ['You specified more than 255 SQL statements within a CREATE TRIGGER or CREATE DBPROC statement.'], ['Delete some of your SQL statements and try to get the same effect using fewer statements.']),
-1119: ('SQL', -1119, 'Too many constraints for this table', ['More conditions have been defined for this table than is permitted. This is either because you have used a specific range of values or because you have explicitly specified certain constraints.'], ['Either check whether or not you really need all the constraints and get rid of any you do not need or group several constraints into one. Repeat the command using the new constraint definitions.']),
-1117: ('SQL', -1117, 'Too complicated trigger qualification', ['The internal representation of the trigger qualification is longer than the space available for this purpose.'], ['Simplify the trigger qualification.']),
-1116: ('SQL', -1116, 'Too long trigger parameters', ['A trigger was defined with parameters whose total length exceeds the possible length.'], ['Try and reduce the number of parameters.']),
-1115: ('SQL', -1115, 'Too many intern columns', ['An ALTER TABLE statement or a CREATE VIEW statement generates a table description either containing more columns than allowed or whose rows exceed the maximum length. Under certain circumstances, this situation can occur because of columns that are invisible to the user.'], ['For a CREATE VIEW statement, check whether some output columns can be omitted. For an ALTER TABLE statement, check whether the specified column width can be decreased. Check also whether previous ALTER TABLE statements generated so many invisible columns that the MODIFY DEFINITION command should be used to remove invisible columns instead of the ALTER DEFINITION command. The effect would be the recopying of the table, a procedure which requires considerable space and time.']),
-1114: ('SQL', -1114, 'Communication packet too small', ['The SQL statement is so long that not all pieces of information to be exchanged between client and server can be stored in the communication packet provided for this purpose.'], ['Simplify the SQL statement or split it into several SQL statements. If this is not possible, check whether the installation parameter PACKET_SIZE can be increased. This parameter indicates the size of the communication packet.']),
-1113: ('SQL', -1113, 'Too many nested function calls', ['The SQL statement contains more nested function calls than can be processed.'], ['Check whether some of the functions within the nesting can be omitted. If this is not possible, check whether the desired effect can be obtained by using a QUERY EXPRESSION in the FROM clause or by generating and reusing a named result set containing a part of the functions.']),
-1112: ('SQL', -1112, 'Constraint too complicated', ['The internal representation of the constraint is longer than the space available for it.'], ['The constraint should be simplified or split into several constraints.']),
-1111: ('SQL', -1111, 'Too many savepoints', ['Within a transaction, too many savepoints were defined.'], ['Check how this uncommonly large number of savepoints occurred. Include the missing COMMIT or ROLLBACK statements in the application.']),
-1110: ('SQL', -1110, 'View definition too long', ['The text of a view definition is longer than the space available for it. This error may also occur with a RENAME COLUMN statement when the view definition maintained internally exceeds the maximum length because of the extension of the name.'], ['Shorten the viewdefinition, e.g. by using short REFERENCE names instead of long table names in SELECT LIST or the SEARCH condition.']),
-1108: ('SQL', -1108, 'Too complicated SQL statement (correlated row too long)', ['The processing of an SQL statement containing at least one correlated subquery requires the generation of an internal result whose rows would exceed the valid length.'], ['Check whether some columns within the SELECT LIST can be omitted or the SQL statement can be reformulated in such a way that less or no correlated columns are used.']),
-1107: ('SQL', -1107, 'Too complicated SQL statement (too many internal commands', ['The SQL statement is so complicated that more internal statements must be generated for it than can be administered for an SQL statement.'], ['Simplify the SQL statement or split it into several SQL statements.']),
-1106: ('SQL', -1106, 'Too complicated SQL statement (too much strategy data)', ['The '], ['Delete some of the search strings containing an OR option.']),
-1105: ('SQL', -1105, 'Too complicated SQL statement (too much data)', ['Within the system, more space is needed to represent the data of the SQL statement than is available.'], ['Simplify the SQL statement or split it into several SQL statements. If this is not possible check whether the installation parameter PACKET_SIZE can be increased, because the amount of storage space available depends on that parameter. An increase in excess of 32 KB will not increase the amount of space any further.']),
-1104: ('SQL', -1104, 'Too complicated SQL statement (KB-stack overflow)', ['Within the system, more elements of an internal structure are needed to represent the SQL statement than are available.'], ['Simplify the SQL statement or split it into several SQL statements. If this is not possible, check whether the installation parameter PACKET_SIZE can be increased, because the size of the internal structure depends on the size of that parameter. The structure size will be adapted from a certain limit value of PACKET_SIZE.']),
-1103: ('SQL', -1103, 'Too complicated SQL statement', ['The number of operations, functions, and conditions is too large.'], ['Simplify the SQL statement. You may also want to try to obtain the effect of the SQL statement with several SQL statements.']),
-1102: ('SQL', -1102, 'Too complicated SQL statement (too many subqueries)', [], ['Simplify the SQL statement or split it into several SQL statements.']),
-1046: ('SQL', -1046, 'ORACLE error the same as Warning3', '', ''),
-1034: ('SQL', -1034, 'SERVERDB not accessible', '', ''),
-1026: ('SQL', -1026, 'Too many differences between old and new view definition', ['A CREATE VIEW statement was specified with the REPLACE option. A view table with the specified name already exists. The existing view definition differs so much from the specified view definition that the definitions depending on this view table can no longer be maintained in a consistent state. The CREATE VIEW therefore fails.'], ['Do not modify the specified view table or check which of the depending definitions, e.g., view tables, privileges, etc., do not match the new view definition. If there are some, delete them before re-executing the CREATE VIEW statement, and recreate them afterwards in an appropriate format.']),
-1025: ('SQL', -1025, 'Too many asynchron requests', ['Your SQL statement will be executed asynchronously, but there are currently not enough resources available.'], ['Execute the SQL statement later.']),
-1023: ('SQL', -1023, 'Too many nested subtransactions', ['The maximum nesting level of subtransactions is 32767. This number was exceeded.'], ['Check which error in application programming generated such a nesting level of subtransactions and correct it.']),
-1017: ('SQL', -1017, 'Too many joins', ['The number of JOIN PREDICATES in a SEARCH CONDITION must not exceed 64.'], ['The expected result can be achieved by issuing several QUERY statements and creating the respective result tables as temporary results. It is also possible to change the SQL statement in such a way that temporary results are implicitly created when a QUERY EXPRESSION is used in a FROM clause.']),
-1015: ('SQL', -1015, 'Too many values', ['In case of an INSERT or UPDATE statement, the number of specified values exceeds the number of column names implicitly specified.'], ['Match the number of specified values in the SQL statement with the number of specified column names. Use a QUERY statement issued on the system table DOMAIN.COLUMNS for an INSERT statement without column name specification to determine the definition of the table used .']),
-1014: ('SQL', -1014, 'Too many source tables', ['The number of underlying tables of the FROM clause of the SQL statement exceeds 16. If a join view table was specified in the FROM clause, the number of base tables underlying the join view table is considered for the calculation.'], ['You can split the SQL statement into two successive SQL statements. It is also possible to bypass this restriction by using a QUERY EXPRESSION in the FROM clause.']),
-1013: ('SQL', -1013, 'Too many order columns', ['The following causes of errors are possible:'], ['Correct the SQL statement in such a way that you can do without one or more columns specified in the ORDER CLAUSE or GROUP CLAUSE respectively.']),
-1012: ('SQL', -1012, 'Too many referential constraint definitions for this tabl', ['Using the ALTER TABLE statement, the attempt was made to create more than 256 REFERENTIAL CONSTRAINT DEFINITIONS for a table that is the referencing table.'], ['Use a QUERY statement issued on the system table DOMAIN.COL_REFS_COL to check the existing CONSTRAINT definitions. The ALTER TABLE statement can only be issued once an existing CONSTRAINT definition has been deleted. Otherwise, do without the new CONSTRAINT definition.']),
-1011: ('SQL', -1011, 'Too many correlated tables', ['The number of correlated tables used within the correlated subqueries must not exceed 16.'], ['Try to formulate the SQL statement in such a way that 16 correlated tables are sufficient. Should this not be possible you have to use several SQL statements to achieve the desired effect.']),
-1010: ('SQL', -1010, 'Too many volumes', ['The number of '], ['Reduce the number of data volumes.']),
-1009: ('SQL', -1009, 'Too many named indexes for this table', '', ''),
-1008: ('SQL', -1008, 'Too many or too few host variables for output', '', ''),
-1007: ('SQL', -1007, 'Too many named indexes for this table', ['A maximum of 256 named indexes can be created per table.'], ['Check whether such a great number of indexes is actually needed. The overhead for maintaining the indexes in case of modifying operations as well as the storage space required for the indexes is probably not in proportion to their benefit.']),
-1006: ('SQL', -1006, 'Too may variables', ['A maximum of 2000 variables may be specified per SQL statement.'], ['Reduce the number of variables specified in the SQL statement. Some variables must be replaced with constant values.  If this is not possible, split the SQL statement into several SQL statements.']),
-1005: ('SQL', -1005, 'Too many monadic operators', ['The issued SQL statement contains at least two monadic operators placed one after the other in an invalid manner.'], ['Correct the monadic operators in the SQL statement..']),
-1004: ('SQL', -1004, 'Too many correlated columns', ['The SQL statement contains at least one correlated subquery. The attempt was made to use more than 64 correlated columns. At most 64 correlated columns can be used. Every single usage of a correlated column is counted.'], ['Rearrange the SQL statement in such a way that 64 correlated columns suffice. Alternatively you may want to try to achieve the effect of this SQL statement with several SQL statements.']),
-1003: ('SQL', -1003, 'Too many buffers requested', ['The storage requirements of the buffers and areas defined by installation parameters are larger than the maximum virtual storage space available for the database system. The execution of the SQL statement was cancelled.'], ['Either decrease the size or number of buffers and areas (installation parameters) or increase the virtual storage space available to the database server. Restart the database.']),
-1002: ('SQL', -1002, 'Too many columns', [], ['\240']),
-1001: ('SQL', -1001, 'Too many lock objects specified', ['The LOCK statement or the option KEEP of a COMMIT statement or ROLLBACK statement contains too many tables or table rows to be locked.'], ['The SQL statement must be formulated using two successive LOCK statements.']),
-1000: ('SQL', -1000, 'Too many lock requests', ['There are too many locks or lock requests.'], ['You can try to repeat the SQL statement at a later time or cancel the transaction. Should this situation occur frequently, then the defined installation parameter MAXLOCKS is too small and should be increased.']),
-955: ('SQL', -955, 'Duplicate name', ['There is already a data object with the specified name.'], ['Repeat the SQL statement with another name.']),
-942: ('SQL', -942, 'Unknown table name', ['A table with the specified name is not known to you. This table may not exist; or this table exists but you have no privileges for it.'], ['Use a QUERY statement issued on the system table DOMAIN.TABLES to find out the names of the tables for which you have privileges. Then correct the table name. It may be sufficient to place the missing <OWNER> in front of it. If correction is not possible, create a table with this name. Check why you have no privileges for the existing table.']),
-925: ('SQL', -925, 'Communication failure', '', ''),
-918: ('SQL', -918, 'Stack overflow', ['Nested calls of DB procedures, triggers or subqueries or very complicated VALUE EXPRESSION resulted in the maximum stack usage allowed for a task. Further nesting is not possible. The execution of the command was cancelled.'], ['\240']),
-917: ('SQL', -917, 'Save/restore write process crash - I/O error', ['The restore or save statement was cancelled.'], ['The error message contains an additional error description which must be interpreted according to the operating system being used. ']),
-915: ('SQL', -915, 'No more memory', [], ['\240']),
-914: ('SQL', -914, 'New volume not accessible', ['You tried to define an additional disk for the data devspace. However, you were unable to do so because there is no disk with the specified name and size which could be accessed.'], ['The error message contains an additional error description which must be interpreted according to the operating system being used.']),
-913: ('SQL', -913, 'Lock request timeout', ['The lock request or an implicit lock conflicts with the locks of another user. The maximum waiting time for granting the lock has elapsed (installation parameter REQUEST_TIMEOUT).'], ['In some cases, the error message contains a more detailed description of the error.']),
-911: ('SQL', -911, 'Work rolled back', ['Your transaction was implicitly cancelled and rolled back by an implicit <ROLLBACK statement>. The following reasons are possible:'], ['In some cases, the error message contains a more detailed description of the error. ']),
-910: ('SQL', -910, 'COSTLIMIT for this user exhausted', ['Execution of the SQL statement would exceed the permissible maximum limit for the processing of the SQL statement (COSTLIMIT value of the user) because of the necessary selection of rows. The COSTLIMIT value is defined in the <CREATE USER>, <CREATE USERGROUP>, <ALTER USER> or <ALTER USERGROUP statement>.'], ['You should check whether the SQL statement is needed in the specified format. You should check whether for example the set of data to be processed could be decreased by specifying more conditions in the <SEARCH CONDITION>; thus decreasing the costs. ']),
-907: ('SQL', -907, 'Space for user session exhausted', ['You have not been connected to the database system, because there is not sufficient free temporary disk space for the CONNECT of a normal database session.'], ['\240']),
-904: ('SQL', -904, 'Space for result tables exhausted', ['The following reasons are possible:'], ['\240']),
-903: ('SQL', -903, 'Host file I/O error', ['An error occurred while operating a command file or host file or a backup device.'], ['The error message contains an additional error description which must be interpreted according to the operating system being used. ']),
-902: ('SQL', -902, 'I/O error', ['During the processing of an SQL statement a read or write operation had to be performed on the data devspace or log devspace. This operation could not be executed successfully. The following reasons are possible:'], ['In some cases, the error message contains an additional description of the error which must be interpreted according to the operating system being used. ']),
-901: ('SQL', -901, 'Log full', ['The log area is full. The following reasons are possible:'], ['Save the log area using the database administration tool.']),
-900: ('SQL', -900, 'Data space full', ['The data area of the server DB is full.'], ['You must increase the server DB by assigning it additional volumes. The SQL statements started beforehand will be finished afterwards.']),
-899: ('SQL', -899, 'Error unknown', ['An unknown error has occurred.'], ['Contact your ']),
-895: ('SQL', -895, 'Whole table my be deleted or updated', ['Precompiler warning that all entries of the table will be deleted or updated.'], ['Check whether this is the desired effect. Otherwise, insert a WHERE clause into the statement.']),
-894: ('SQL', -894, 'Trace parameter structure not allowed', ['There is a syntax error in SET TRACE LINE.'], ['Correct the SET TRACE LINE statement.']),
-893: ('SQL', -893, 'Too many hostvariables', [], ['Reduce the number of parameters in the SQL statement to 300 or less.']),
-892: ('SQL', -892, 'Variable may be overflow', [], []),
-890: ('SQL', -890, 'Input line longer than right margin', ['A line of the source file is longer than the right margin.'], ['If allowed, adjust the right margin using the option MARGINS. Otherwise shorten the line.']),
-889: ('SQL', -889, 'Input line longer than 512 characters', ['A line of a precompiler input file must not exceed 512 characters.'], ['Shorten the line concerned.']),
-888: ('SQL', -888, 'Could not load libpcr', '', ''),
-887: ('SQL', -887, 'Too long WHENEVER action', ['A maximum of 50 bytes are available to define the WHENEVER action.'], ['Reduce the number of characters, e.g. by shortening the names.']),
-886: ('SQL', -886, 'DECLARE SECTION BEGIN or END missing', ['The DECLARE SECTION has an incorrect delimiter statement.'], ['Every DECLARE SECTION must be enclosed in BEGIN DECLARE SECTION and END DECLARE SECTION.']),
-885: ('SQL', -885, 'Variable may be truncated', ['The range of values for the database column is smaller than that of the SQL variables. When the value is inserted into the column or when values are compared, the value of the SQL variables may be truncated and consequently be incorrect.'], ['If this is not desired, you must change the format of the column or SQL variables.']),
-884: ('SQL', -884, 'Missing indicator variable', ['The database system permits null values for the variable. For this it requires an indicator variable.'], ['In addition to the SQL variable you must specify an indicator variable. This specification is not necessary when it is ensured that null values will not occur.']),
-883: ('SQL', -883, 'Invalid runtime options', ['The precompiler or runtime options are incorrect.'], ['Correct the options.']),
-882: ('SQL', -882, 'Missing user name for connect', ['No user/password combination was found for an implicit CONNECT initiated by the CHECK option.'], ['Write a static CONNECT statement as the first SQL statement in the program, apply the USER option or create an XUSER file for an implicit CONNECT.']),
-881: ('SQL', -881, 'Unknown type name', ['The type definition is not known.'], ['Correct the type name or define a type.']),
-880: ('SQL', -880, 'Unknown statement name', ['The name of the statement is not known.'], ['Ignore the PREPARE statement or correct it.']),
-879: ('SQL', -879, 'Unknown precompiler statement', ['The precompiler statement is unknown or incorrect.'], ['Ignore the precompiler statement or correct it.']),
-878: ('SQL', -878, 'Unknown record name', ['The name of the record is not known.'], ['Correct the name or declare a record.']),
-877: ('SQL', -877, 'Unknown parameter name', ['The name of the parameter is not known.'], ['Correct the name or declare an indicator.']),
-876: ('SQL', -876, 'Unknown macro number', ['The macro number is not known. The SET MACRO statement was not executed for the specified macro number.'], ['Enter the correct number or define an appropriate macro.']),
-874: ('SQL', -874, 'Unknown cursor name', ['The name of the cursor is not known.'], ['Correct the name or define a cursor.']),
-873: ('SQL', -873, 'Unknown constant name', ['The name of the constant is not known.'], ['Correct or declare the name.']),
-872: ('SQL', -872, 'Number of columns > number of parameters', ['Fewer SQL variables were specified in the statement than columns existed in the table.'], ['If this is not desired, either add SQL variables or reduce the number of columns in the table.']),
-871: ('SQL', -871, 'Too many variable definitions', ['The number of SQL variable definitions is too great.'], ['Break down the SQL statements into several modules or reduce the number of SQL variable declarations. The maximum number is 10000.']),
-870: ('SQL', -870, 'Too many type definitions', ['The number of type definitions is too great.'], ['Break down the SQL statements into several modules or reduce the number of type definitions. The maximum number is 500.']),
-863: ('SQL', -863, 'Invalid option', '', ''),
-862: ('SQL', -862, 'ABAP Exception', '', ''),
-861: ('SQL', -861, 'ABAP Descriptor not set', '', ''),
-860: ('SQL', -860, 'Too many constants declared', ['Too many SQL constants are declared.'], ['The database application should be modularized. The maximum number of constants is 100.']),
-859: ('SQL', -859, 'Number of columns < number of parameters', ['More SQL variables are specified in the statement than columns are available in the table.'], ['If this is not desired, add columns to the table or reduce the number of SQL variables.']),
-858: ('SQL', -858, 'Storage class not allowed', ['The C storage class is not allowed.'], ['Choose another storage class.']),
-857: ('SQL', -857, 'Missing SERVERDB', ['No SET SERVERDB statement was issued for the second or any following database connection.'], ['Specify SET SERVERDB before the CONNECT statement or in the XUSER file.']),
-856: ('SQL', -856, 'Invalid loop parameter value', ['In an SQL array statement, the value of the <LOOP PARAMETER> is set to <=\2400.'], ['Set the <LOOP PARAMETER> to a value > 0.']),
-855: ('SQL', -855, 'SQL variable must be an array', ['SQL variables must be array structures in an SQL array statement.'], ['Define and specify the SQL variable correctly.']),
-854: ('SQL', -854, 'Parameters must be question marks', ['In PREPARE statements, only question marks are allowed for parameter specifications.'], ['Replace the SQL variable with a question mark.']),
-853: ('SQL', -853, 'Precompiler syntax check only', ['Although the option CHECK was specified, the syntax of this statement could only be checked for the precompiler run. No entries were made to the data dictionary of the database.'], ['To obtain information about possible errors, run the application with the TRACE option.']),
-852: ('SQL', -852, 'Missing program file', ['The source file is unknown.'], ['Check whether the file is available or the spelling of the filename is correct.']),
-851: ('SQL', -851, 'Missing input file name', ['A name specified for an INCLUDE file is unknown.'], ['Check whether the file is available or the spelling of the filename is correct.']),
-850: ('SQL', -850, 'Statement termination expected', ['The termination symbol is missing in the preceding SQL statement. It is set by the precompiler.'], ['If there are no side effects, insert the termination symbol into the statement.']),
-849: ('SQL', -849, 'Invalid data definition', ['The SQL variable or data definition is invalid or not allowed. The variable definition is not known as an SQL variable.'], ['Declare the SQL variable name or the data in the DECLARE SECTION, or correct the name or data.']),
-848: ('SQL', -848, 'Invalid unsigned integer', ['An unsigned integer was expected but not found.'], ['Correct the SQL statement.']),
-847: ('SQL', -847, 'Invalid type definition', ['The type definition or clause is invalid or not allowed.'], ['Correct the definition or clause, or remove it from the DECLARE SECTION.']),
-846: ('SQL', -846, 'Invalid statement in section', ['A statement in the section is invalid.'], ['Correct the statement or use another SQL statement.']),
-845: ('SQL', -845, 'Invalid SQL statement', ['The SQL statement is invalid or unknown.'], ['Correct the SQL statement or use another SQL statement.']),
-844: ('SQL', -844, 'Invalid record name', ['The record name is invalid or unknown.'], ['Declare a record or use another SQL variable.']),
-843: ('SQL', -843, 'Invalid parameter name', ['The parameter name is not an identifier.'], ['Correct the name in accordance with the notation of identifiers.']),
-842: ('SQL', -842, 'Parameter and indicator do not match', ['Parameters and indicators are defined with different types ('], ['Use indicator variables which have another type.']),
-841: ('SQL', -841, 'Invalid precompiler option', ['A precompiler option is invalid or unknown.'], ['For the exact error description, see the precompiler listing or the SQLERROR file. Check the options and specify them correctly.']),
-840: ('SQL', -840, 'Invalid numeric macro value', ['The macro number is invalid.'], ['Specify a number between 1 and 128 for the macro.']),
-839: ('SQL', -839, 'Invalid macro value', ['An error occurred when substituting the macro.'], ['Specify the macro value in accordance with the syntax.']),
-838: ('SQL', -838, 'Invalid declarator', ['The declarator is invalid.'], ['Correct the declarator within the DECLARE SECTION.']),
-837: ('SQL', -837, 'Data definition not allowed', ['The syntax of the SQL data type is incorrect or the SQL data type is invalid.'], ['Correct the data definition or construct a valid alternative.']),
-836: ('SQL', -836, 'Invalid C preprocessor command', ['The C preprocessor command line is incorrect.'], ['Correct the command in accordance with the C rules.']),
-835: ('SQL', -835, 'INCLUDE file open error', ['The INCLUDE file could not be opened.'], ['Check whether the file is available or the spelling of the filename is correct. For the exact error description, see the file ']),
-834: ('SQL', -834, 'INCLUDEs must not be nested', ['Another INCLUDE statement was found within an INCLUDE file.'], ['Remove the inner INCLUDE statement.']),
-833: ('SQL', -833, 'Illegal INCLUDE position', ['An INCLUDE statement is not at the correct position in the module.'], ['Place the INCLUDE statement in the correct position.']),
-832: ('SQL', -832, 'File write error', ['A file could not be written. This may be a device failure.'], ['Check whether the file is available or the spelling of the filename is correct. For the exact error description, see the file ']),
-831: ('SQL', -831, 'File read error', ['A file could not be read. This may be a device failure.'], ['Check whether the file is available or the spelling of the filename is correct. For the exact error description, see the file ']),
-830: ('SQL', -830, 'File open error', ['A file could not be opened.'], ['Check whether the file is available or the spelling of the filename is correct. For the exact error description, see the file ']),
-829: ('SQL', -829, 'File close error', ['An error occurred when closing a file. This is a device failure or system error.'], ['Try again to close the file. For the exact error description, see the file ']),
-828: ('SQL', -828, 'Duplicate variable name', ['The name was already specified for an SQL variable.'], ['Rename the SQL variable.']),
-827: ('SQL', -827, 'Duplicate type definition', ['The name was already specified for an SQL type definition.'], ['Rename the SQL type.']),
-826: ('SQL', -826, 'Duplicate statement name', ['The name was already specified for a statement.'], ['Rename the statement.']),
-825: ('SQL', -825, 'Duplicate field name in record', ['A name is used twice in an SQL record definition to specify components.'], ['Rename one of the record components.']),
-824: ('SQL', -824, 'Statement in conflict with COMPATIBLE option', ['The option COMPATIBLE is set, and an SQL array statement was specified with the keyword FOR. The option COMPATIBLE was used in conjunction with array statements. Array statements are only supported from Release 3.1 onwards. '], ['Remove the COMPATIBLE option or change the array statement. ']),
-823: ('SQL', -823, 'Integer too large, greater than 32767', ['The constant must not be greater than 32767 (two bytes).'], ['Choose a smaller constant value.']),
-822: ('SQL', -822, 'Invalid constant definition', ['The constant definition is invalid.'], ['Correct the constant definition within the DECLARE SECTION.']),
-821: ('SQL', -821, 'Session not connected', '', ''),
-820: ('SQL', -820, 'Invalid declare statement', ['The keyword FOR was not found in the DECLARE CURSOR statement.'], ['Insert the keyword FOR into the DECLARE CURSOR statement.']),
-819: ('SQL', -819, 'Paramter in SQL statement not allowed', ['Only an SQL statement without parameter specifications is permitted. Either an SQL statement with parameters but without a USING part was passed with an EXECUTE, or an error occurred in the parameter list.'], ['Add the USING clause, or use an SQL statement without parameters, or correct the parameter list.']),
-818: ('SQL', -818, 'Missing macro parameter initialization', ['The macro was not initialized.'], ['Insert the SQL statement SET MACRO into the application program.']),
-817: ('SQL', -817, 'Incompatible data types', ['The data type of the SQL variable or parameter is not compatible with the database data type.'], ['Change the data type of the SQL variable or parameter to match the data type of the database table column.']),
-816: ('SQL', -816, 'Trace file write error', ['An error occurred when writing into the trace file. Writing of the trace file was cancelled. The statement in which the error occurred was not executed.'], ['Check the file attributes and change them, if necessary. For the exact error description, see the file ']),
-815: ('SQL', -815, 'Trace file open error', ['The trace file could not be opened. Writing of the trace file was disabled. The statement in which the error occurred was not executed.'], ['Check the file attributes and change them, if necessary. For the exact error description, see the file ']),
-814: ('SQL', -814, 'Trace file close error', ['The trace file could not be closed. The error in the program was ignored.'], ['Modify the file attributes (characteristics). For the exact error description, see the file ']),
-813: ('SQL', -813, 'SERVERDB must be restarted', ['The database system is not running, or an invalid database name was specified in the program.'], ['The DB administrator must start the database, or the user must modify the program or XUSER file.']),
-812: ('SQL', -812, 'Parameter list too short', ['Fewer parameters have been specified in a statement than are needed in the pertinent EXECUTE statement.'], ['Modify the number of parameters in such a way that it corresponds to the specifications made in the column list.']),
-811: ('SQL', -811, 'Numeric output parameter overflow', ['An database value is too large for the SQL variable or the parameter.'], ['Enlarge the value range for the SQL variable or parameter.']),
-810: ('SQL', -810, 'Connection already in use', '', ''),
-809: ('SQL', -809, 'Missing indicator variable, output parameter', ['The indicator variable required for returning the NULL value to the SQL variable is missing.'], ['Specify the indicator variable with the parameter.']),
-808: ('SQL', -808, 'Not yet implemented', ['The function has not yet been implemented.'], ['Please consult the release information.']),
-807: ('SQL', -807, 'Connection down, session released', ['All database connections were closed with RELEASE.'], ['Establish a new connection using CONNECT.']),
-806: ('SQL', -806, 'DB session number not allowed', ['The specified database session number is invalid.'], ['Insert a database session number between 1 and 8 into the application program.']),
-805: ('SQL', -805, 'Program must be precompiled', ['The common type definitions of the precompiler runtime system or of the include files no longer correspond to the precompiler types.'], ['Check the release numbers of precompiler, precompiler runtime system, and include files and precompile again, if necessary.']),
-804: ('SQL', -804, 'Parameter list too long', ['More parameters have been specified in a statement than are permitted in the pertinent EXECUTE statement.'], ['Modify the number of parameters in such a way that it corresponds to the specifications made in the column list.']),
-803: ('SQL', -803, 'Trace error', '', ''),
-802: ('SQL', -802, 'Invalid numeric input parameter value', ['The input value cannot be converted.'], ['Specify the value in a valid notation (see the Precompiler manuals).']),
-801: ('SQL', -801, 'Input parameter cannot be NULL value', ['The value of an input parameter must not be a null value because null values are not permitted in the column.'], ['Modify the program or change the column definition in the CREATE TABLE statement.']),
-779: ('SQL', -779, 'PUTVAL: No long columns found', '', ''),
-778: ('SQL', -778, 'Conversion to UNICODE impossible', ['An error occurred when converting char data into Unicode data.'], ['Check whether a conversion such as this is really needed. You may have to change the declaration of the host variables for the char data.']),
-777: ('SQL', -777, 'Conversion from UNICODE impossible', ['An error occurred when converting Unicode data into char data.'], ['Check whether a conversion such as this is really needed. You may have to change the declaration of the host variables for the char data.']),
-776: ('SQL', -776, 'Datafile close error', ['An error occurred when closing a datafile for the processing of Long columns.'], ['Look up in the trace file *.pct in which column the error occurred. Then check the datafile.']),
-775: ('SQL', -775, 'Datafile read error', ['An error occurred when reading a datafile for the processing of Long columns.'], ['Look up in the trace file *.pct in which column the error occurred. Then check the datafile.']),
-774: ('SQL', -774, 'Datafile write error', ['An error occurred when writing a datafile for the processing of Long columns.'], ['Look up in the trace file *.pct in which column the error occurred. Then check the datafile.']),
-773: ('SQL', -773, 'Datafile open error', ['An error occurred when opening a datafile for the processing of Long columns.'], ['Look up in the trace file *.pct in which column the error occurred. Then check the datafile.']),
-772: ('SQL', -772, 'Multibyte char set not allowed', ['The CONNECT statement received an unknown multibyte specification.'], ['Correct the CONNECT statement. Please see the reference manual for more information.']),
-771: ('SQL', -771, 'LONG column exists in table definition', ['The table from which the host variables are generated contains a Long column.'], ['The user can change the host variable generated for this column.']),
-770: ('SQL', -770, 'Macro in FETCH set SQLOPT=&quot;-B 0&quot;', ['FETCH statements are executed as array statements, whenever possible. If macros are used in the FETCH statement, errors may occur and records be lost.'], ['When using macros within FETCH statements, set the runtime option MFETCH(0). This option prevents FETCH statements from being executed as array statements.']),
-769: ('SQL', -769, 'Pointer component not allowed', ['Pointers are not allowed within structures.'], ['Do not specify components as pointers.']),
-768: ('SQL', -768, 'Invalid escape value', ['The input host variable is longer than one character.'], ['Use a correct host variable.']),
-767: ('SQL', -767, 'Unterminated C string', ['The zero byte delimiter is missing.'], ['Insert a zero byte.']),
-763: ('SQL', -763, 'Variable not allowed as ARRAY', ['Scalar host variables are used in an ARRAY statement.'], ['Instead of scalar variables, use arrays only; otherwise do without the ARRAY statement.']),
-762: ('SQL', -762, 'EXEC ORACLE command has been deleted', ['The precompiler removes all statements that are preceded by EXEC ORACLE.'], ['This is a warning which may provide indications to possible compiler errors.']),
-760: ('SQL', -760, 'Memory allocation failed', ['The available main memory is too small or write-protected.'], ['Check the program for a possible programming error. Increase the main memory or contact your ']),
-759: ('SQL', -759, 'Include file produced by user', ['During the precompiler run, the DECLARE SECTION is newly created by a CONNECT of the user <user>.'], ['Check whether the table of this user is the correct one.']),
-758: ('SQL', -758, 'Include file exists on disk', ['The DECLARE SECTION is not generated during the precompiler run. The file is already available.'], ['Check whether the used file is the current one.']),
-757: ('SQL', -757, 'XUSER error', '', ''),
-756: ('SQL', -756, 'Different SQLMODEs not allowed', ['An application program may only run in one SQLMODE.'], ['Change the CONNECT statement. Implicit CONNECTs only function in INTERNAL mode. The specifications made in the XUSER file are not applied in this case.']),
-753: ('SQL', -753, 'Output parameter with CONST type', ['An output parameter must not be declared as CONST type in C.'], ['Declare another parameter in the application program.']),
-752: ('SQL', -752, 'Session already connected', ['A database session has already been opened with this number.'], ['Either close the previous database session or remove the CONNECT from the application program.']),
-751: ('SQL', -751, 'Numeric input parameter overflow', ['The numeric input value is too large for the database.'], ['Check the size of the input value and of the range of values valid for the database and modify them, if necessary.']),
-750: ('SQL', -750, 'FFETCH or ARRAY-FETCH and FETCH mix not allo', ['ARRAY FETCH and FETCH statements cannot be issued on the same result set.'], ['All statements which refer to the same result set must be specified either as ARRAY FETCH or FETCH.']),
-743: ('SQL', -743, 'Input string too long', ['The contents of a character string are longer than the database is capable of storing.'], ['Set the input variable to a string which corresponds to the length of the database variable or adapt the input variable to the format used in the database.']),
-740: ('SQL', -740, 'Array size mismatch', ['In mass statements the parameters have different sizes.'], ['The smallest size of all the parameters is set. If this is not desired, set all the sizes to the same value.']),
-735: ('SQL', -735, 'No syntax check for CONNECT command', ['CONNECT statements that are not used to establish the connection for the check run are not checked for syntax errors during precompilation.'], ['Pay special attention to the correct spelling when entering the statement.']),
-734: ('SQL', -734, 'Pointer variable not allowed here', ['SQL variables defined as pointers are not allowed in Long columns because the maximum length of these variables is not known.'], ['Specify the SQL variable as a CHARACTER ARRAY.']),
-733: ('SQL', -733, 'Variable is declared as a pointer', ['The SQL variable was defined as a pointer in the DECLARE SECTION.'], ['As no fixed size is specified for a pointer, the name of the variable and COLLENGTH are indicated in the next error line. COLLENGTH is the maximum size of the SQL pointer variables. This size is needed for data conversion.']),
-732: ('SQL', -732, 'Index of component out of', ['The specified index is not in the range of values of the array.'], ['Specify an index which is within the range of values.']),
-731: ('SQL', -731, 'Component name too', ['Structure names become longer than 18 bytes by expansion.'], ['Shorten the structure names in the table definition. If this is not possible, specify the column names separately.']),
-730: ('SQL', -730, 'Nested comment not closed', ['Nested comments are not regularly closed in the source program.'], ['The number of opening commentary symbols must equal the number of closing commentary symbols.']),
-729: ('SQL', -729, 'Source code may be truncated', ['The precompiler only recognizes text that is placed within the line delimiters. The line delimiters depend on the programming language. The warning means that text outside the line delimiters was discovered. This text is ignored by the precompiler.'], ['If this effect is desired, the warning may be ignored. Otherwise, the text must be written to the next line or the line delimiters must be modified.']),
-724: ('SQL', -724, 'Duplicate substructure name', ['The name specified for the search for an SQL variable is not unique, because it identifies a substructure.'], ['Specify the name of the complete structure with the SQL variable.']),
-721: ('SQL', -721, 'Macro not initiated, no SQLCHECK', ['No SET MACRO was performed. Therefore the SQL statement cannot be checked.'], ['Ensure that SET MACRO is performed before the SQL statement within the program flow.']),
-720: ('SQL', -720, 'SQLCODE <no> comes from SYSPROFILE command', ['The database error <no> occurred when writing the SYSPROFILE.'], ['For error analysis and correction refer to the instructions given under the corresponding number.']),
-719: ('SQL', -719, 'Unknown LOCALSYSUSER.SYSPROFILE table', ['When enabling the PROFILE option, no SYSPROFILE table could be found.'], ['The LOCALSYSUSER must create this table, or the application program must be started without the PROFILE option.']),
-715: ('SQL', -715, 'Missing username or password for connect', ['A username or password specification is missing in a CONNECT statement, or there is no XUSER file for an implicit CONNECT.'], ['Enter the user name and password for the CONNECT statement via Options, or open an XUSER file.']),
-712: ('SQL', -712, 'Too many parameters, SQLMAX too small', ['In an SQLDA area, an SQLVAR entry was accessed which is no longer available (maximum number of SQLVAR entries\240<\240index of the SQLVAR entry).'], ['Update the maximum number of SQLVAR elements or correct the index.']),
-711: ('SQL', -711, 'Implicit CONNECT: missing user or SERVERDB', ['During execution of an implicit CONNECT, the user entries or the database name could not be found.'], ['Open an XUSER file, or enter the CONNECT parameters using runtime options.']),
-710: ('SQL', -710, 'Missing select PARSID', ['The parsing information of a FETCH/CLOSE command cannot be assigned to any result set.'], ['Contact your ']),
-709: ('SQL', -709, 'Connect failed, check SERVERDB', ['An error was detected while processing the CONNECT statement.'], ['\240']),
-708: ('SQL', -708, 'SERVERDB system not available', ['The database exists, but it is in the startup or shutdown phase, with the result that a connection cannot be established at the moment.'], ['Repeat the CONNECT at a later time.']),
-707: ('SQL', -707, 'Invalid CONNECT statement syntax', ['There is an error in the CONNECT statement syntax.'], ['Take the exact syntax description from the Reference manual. Correct the statement accordingly.']),
-706: ('SQL', -706, 'SQL statement too long (buffer overflow)', ['The SQL statement does not fit the buffer used for communication between the application program and the database system.'], ['Change the statement or break down the SQL statement into two or more SQL statements. ']),
-703: ('SQL', -703, 'Duplicate FETCH statement for same select in program', ['When the MFETCH option is set, only one FETCH statement is allowed per result table.'], ['Modify the application or run it without MFETCH option.']),
-702: ('SQL', -702, 'Missing variable address in SQLDA', ['The address of a program variable was not set in the SQLDA.'], ['Write the address into the SQLDA at the HOSTVARADDR position.']),
-602: ('SQL', -602, 'System error', ['Normal database operations were disrupted. Possibly the database is no longer consistent. An implicit SHUTDOWN may have been performed.'], ['Shut down the database and inform your ']),
-530: ('SQL', -530, 'Referential integrity violated', ['The following reasons are possible:'], ['\240']),
-320: ('SQL', -320, 'ANSI error the same as return code +320', '', ''),
-300: ('SQL', -300, 'ANSI error the same as return code +300', '', ''),
-250: ('SQL', -250, 'ANSI error the same as return code +250', '', ''),
-123: ('SQL', -123, 'No more log to save', ['You tried to save the log AREA. This is not possible or necessary since the database system wrote no or very few entries to the log AREA since the log AREA was last saved.'], ['No user action is required.']),
-119: ('SQL', -119, 'SERVERDB already activated', ['Installation of the serverdb was not performed without errors.'], ['Check the installation protocol. Remove the error and carry out the installation again, if necessary.']),
-118: ('SQL', -118, 'SERVERDB must be activated', ['Installation of the serverdb did not take place without errors.'], ['Check the installation protocol. Remove the error and carry out the installation again, if necessary.']),
-115: ('SQL', -115, 'Table is read only', ['The attempt was made to perform an <INSERT>, <UPDATE> OR <DELETE statement>. But the specified table only allows reading SQL statements because it was previously loaded with the NOLOG option.'], ['The read-only mode can be implicitly cancelled saving data or pages using the database administration tool.']),
-111: ('SQL', -111, 'Incompatible incremental backup', ['The database version to be loaded is not the follow-up version of the current database state.'], ['Choose the correct database version.']),
-108: ('SQL', -108, 'Table or index dropped or content deleted', ['While an SQL statement was processed without any read locks, another database user deleted a table. The execution of the SQL statement was therefore cancelled.'], ['Clarify the organizational error in the user environment.']),
-107: ('SQL', -107, 'SQL statement not allowed for this instance', ['The database instance is unable to execute this SQL statement.'], ['You must do without the SQL statement for this database instance.']),
-106: ('SQL', -106, 'Table unloaded or content deleted', ['The table cannot currently be accessed. The following reasons are possible:'], ['Execute the SQL statement.']),
-104: ('SQL', -104, 'DBM command impossible at this time', '', ''),
-103: ('SQL', -103, 'SQL statement no available for this application', '', ''),
-102: ('SQL', -102, 'SQL statement cancelled', ['The SQL statement currently executed was terminated by user or operator intervention.'], ['No user action is required in interactive operation. In other cases, reset the transaction with a ROLLBACK statement.']),
-101: ('SQL', -101, 'SQL statement not available in this DB mode', ['In order to execute the SQL statement, the database must be in OFFLINE or ONLINE '], ['Ensure that the database instance is in the required mode. ']),
-75: ('SQL', -75, 'Too many SQL statements (work rolled back)', ['Your transaction was implicitly cancelled and rolled back by an implicit <ROLLBACK statement>. The database session was implicitly terminated, since you had issued too many SQL statements or had performed too many transactions within a session.'], ['After a new CONNECT statement the transaction may be repeated.']),
-71: ('SQL', -71, 'Session terminated by shutdown (work rolled back)', ['Your transaction was implicitly cancelled and rolled back by an implicit <ROLLBACK statement>. The database session was canceled implicitly because a database shutdown was forced in parallel by the database administration tool. To speed up a later restart, the database tries to reset and not just terminate open transactions within a short period.'], ['Repeat the CONNECT statement and the transaction when the serverdb is ready for operation.']),
-70: ('SQL', -70, 'Session inactivity timeout (work rolled back)', ['Your transaction was implicitly cancelled and rolled back by an implicit <ROLLBACK statement>. The database session was implicitly terminated, since you failed to carry out any database operations within a certain period of time (installation parameter SESSION_TIMEOUT or TIMEOUT value specified with the <CONNECT statement>).'], ['Repeat the CONNECT statement, possibly specifying a higher TIMEOUT value. ']),
-65: ('SQL', -65, 'Work rolled back', ['The user transaction was canceled implicitly and reset with an implicit ROLLBACK statement because the log AREA is full.'], ['The error text contains a precise description of the error. ']),
-60: ('SQL', -60, 'Work rolled back', ["The user's transaction was implicitly cancelled and reset by a ROLLBACK statement. for the following possible reasons:"], ['In some cases, the error message contains a more detailed description of the error. ']),
-54: ('SQL', -54, 'Lock collision', ['When the option (NOWAIT) is specified in the LOCK statement or in the LOCK option, this message signals that the lock request conflicts with the locks of other users.'], ['\240']),
-51: ('SQL', -51, 'Lock request timeout', ['The lock request or an implicit lock request conflicts with the locks of another user. The maximum waiting time for granting the lock has elapsed (installation parameter REQUEST_TIMEOUT).'], ['In some cases, the error message contains a more detailed description of the error.']),
-50: ('SQL', -50, 'Lock request timeout', ['The lock request or an implicit lock request conflicts with the locks of another user. The maximum waiting time for being granted the lock has elapsed (installation parameter REQUEST_TIMEOUT).'], ['In some cases, the error message contains a more detailed description of the error.']),
-40: ('SQL', -40, 'Lock collision', ['When the option (NOWAIT) is specified in the LOCK statement or in the LOCK option, this message signals that the lock request conflicts with the locks of other users.'], ['\240']),
-36: ('SQL', -36, 'Foreign key integrity violation', ['Where there is an INSERT or <UPDATE statement> issued on a join view table, the column values functionally depending on the <REFERENCING COLUMN>s of the referencing table conflict with the existing column values.'], ['This conflict may be solved by changing either the column values specified in the INSERT or <UPDATE statement>, or the existing values.']),
-35: ('SQL', -35, 'Referential integrity violated', ['This may be caused by one of the following:'], ['\240']),
-32: ('SQL', -32, 'View violation', ["An INSERT or UPDATE statement was issued for a view table. At least one of the rows specified in the SQL statement does not satisfy the SEARCH CONDITIONs of all underlying view tables defined 'WITH CHECK OPTION'."], ['Display the definition of the view table using a QUERY statement issued on the system table DOMAIN.VIEWDEFS. Correct the INSERT or UPDATE statement according to this definition.']),
-30: ('SQL', -30, 'Integrity violation', ['Insertions or updates would violate integrity constraints specified in the definition of the base or view table.'], ['The error message specifies the column which would violate the integrity constraints.']),
-25: ('SQL', -25, 'Duplicate secondary key', ['There is already a table row with the specified secondary key. UNIQUE was specified for the secondary key.'], ['To avoid a key value collision, correct the value of the key to be inserted in the SQL statement.']),
-20: ('SQL', -20, 'Duplicat key', ['There is already a table row with the key to be inserted.'], ['Check whether the existing table row contains the desired values. If this is not the case, check whether values in the existing table row can be replaced with the desired values. If a new table row must be inserted, change the value of the key to be inserted in the SQL statement in order to prevent key collisions.']),
-12: ('SQL', -12, 'Execution failed, parse again, monitor started', '', ''),
-11: ('SQL', -11, 'Long column is undefined (empty)', '', ''),
-10: ('SQL', -10, 'More than one SQL statement included', '', ''),
-9: ('SQL', -9, 'Use new parsinfo', '', ''),
-8: ('SQL', -8, 'Execution failed, parse again', ['The parse identification ('], ['Reparse the statement.']),
-7: ('SQL', -7, 'Wrong messcodetype', '', ''),
-5: ('SQL', -5, 'Wrong messagetype ( use ADBS )', '', ''),
-4: ('SQL', -4, 'COSTWARNING exhausted', '', ''),
-1: ('SQL', -1, 'Duplicate key in index', ['There is already a table row with the specified secondary key. UNIQUE was specified for the secondary key.'], ['To avoid a key value collision, correct the value of the key to be inserted in the SQL statement.']),
0: ('SQL', 0, 'Success', ['The SQL statement was successfully executed.'], ['No user action is required. ']),
100: ('SQL', 100, 'Row not found', ['There is no (further) table row which meets the criterion.'], ['No user action is required.']),
110: ('SQL', 110, 'LONG column is undefined (empty)', '', ''),
200: ('SQL', 200, 'Duplicate secondary key', ['There is already a table row with the key to be inserted. '], ['Check whether the existing table row contains the desired values. If this is not the case, check whether values in the existing table row can be replaced with the desired values. If a new table row must be inserted, change the value of the key to be inserted in the SQL statement in order to prevent key collisions.']),
250: ('SQL', 250, 'Duplicate secondary key', ['There is already a table row with the specified secondary key. UNIQUE was specified for the secondary key. '], ['To avoid a key value collision, correct the value of the key to be inserted in the SQL statement. ']),
300: ('SQL', 300, 'Integrity violation', ['Insertions or updates would violate integrity constraints specified in the definition of the base or view table.'], ['The error message specifies the column which would violate the integrity constraints. ']),
320: ('SQL', 320, 'View violation', ["An INSERT or <UPDATE statement> was issued for a view table. At least one of the rows specified in the SQL statement does not satisfy the SEARCH CONDITIONs of all underlying view tables defined 'WITH CHECK OPTION'. "], ['Display the definition of the view table using a <QUERY statement> issued on the system table DOMAIN.VIEWDEFS. Correct the INSERT or <UPDATE statement> according to this definition.']),
350: ('SQL', 350, 'Referential integrity violated', ['The following causes are possible: '], ['\240']),
360: ('SQL', 360, 'Foreign key integrity violation', ['In an INSERT or UPDATE statement issued on a join view table, the column values functionally depending on the <REFERENCING COLUMN>s of the referencing table conflict with the existing column values.'], ['This conflict may be solved by changing either the column values specified in the INSERT or UPDATE statement, or the existing values.']),
400: ('SQL', 400, 'Lock collision', ['When the option (NOWAIT) is specified in the LOCK statement or in the LOCK option, this message signals that the lock request conflicts with the locks of other users. '], ['\240']),
450: ('SQL', 450, 'Lock collision caused by pending locks', ['The lock request made by the SQL statement conflicts with locks which cannot be resolved at present because they belong to a pending transaction. The pending transaction cannot be concluded because there is no connection to the releasing serverdb. '], ['The SQL statement should not be reissued until the pending transaction has been resolved; i.e. until it has been possible to reconnect to the particular serverdb.']),
500: ('SQL', 500, 'Lock request timeout', [], ['\240']),
600: ('SQL', 600, 'Work rolled back', ['Your transaction was implicitly cancelled and rolled back by an implicit <ROLLBACK statement>'], ['In some cases, the error message contains a more detailed description of the error.']),
650: ('SQL', 650, 'Work rolled back', ['The user transaction was canceled implicitly and reset with an implicit <ROLLBACK statement> because the log devspace is full.'], ['The error text contains a precise description of the error. ']),
700: ('SQL', 700, 'Session inactivity timeout (work rolled back)', ['Your transaction was implicitly cancelled and rolled back by an implicit <ROLLBACK statement>. The database session was implicitly terminated, since you failed to carry out any operations within a certain period of time (installation parameter SESSION_TIMEOUT or TIMEOUT value specified with the <CONNECT statement>).'], ['Repeat the <CONNECT statement> and specify a larger TIMEOUT value, if necessary.']),
710: ('SQL', 710, 'Session terminated by shutdown (work rolled back)', '', ''),
750: ('SQL', 750, 'Too many SQL statements (work rolled back)', ['Your transaction was implicitly cancelled and rolled back by an implicit <ROLLBACK statement>. The database session was implicitly terminated, since you had issued too many SQL statements or had performed too many transactions within a session.'], ['The transaction can be repeated after a new <CONNECT statement>.']),
800: ('SQL', 800, 'Implicit SERVERDB restart', '', ''),
802: ('SQL', 802, 'Numeric operation exception error', '', ''),
1403: ('SQL', 1403, 'Row not found', '', ''),
25601: ('Replication Manager', 25601, 'Character string for the NULL value in column <column nam', ['Warning when downloading data using the DATAEXTRACT command.'], ['No user action is required.']),
25602: ('Replication Manager', 25602, 'Integer values of column <column name> may become to larg', ['Warning when downloading data using the DATAEXTRACT command.'], ['No user action is required.']),
25603: ('Replication Manager', 25603, 'Literal <literal> will be truncated', ['Warning when downloading data using the DATAEXTRACT command.'], ['No user action is required.']),
25604: ('Replication Manager', 25604, 'Supernumerary specifications for the LONG data file will', ['This warning appears if you are downloading data using the DATAEXTRACT command and you want to download LONG columns.'], ['No user action is required.']),
25605: ('Replication Manager', 25605, 'Warning when downloading data; neither the header nor the', ['Warning when uploading or updating data from binary data files using the commands FASTLOAD, DATALOAD, or DATAUPDATE.'], ['No user action is required.']),
25606: ('Replication Manager', 25606, 'Different byte swap of source and target computer. Check', ['Warning when uploading data using the TABLELOAD command.'], ['Check the LONG values in the database after they have been uploaded: ']),
25607: ('Replication Manager', 25607, 'The USAGE value is too low and will be ignored', ['Warning when uploading data using the FASTLOAD command.'], ['No user action required.']),
25608: ('Replication Manager', 25608, 'No restart file found. Upload will restart', ['Warning when uploading data using the TABLELOAD ALL or the TABLELOAD USER command.'], ['No user action required.']),

}

def wordWrapLine (line, maxline = 60):
    result = []
    restline = line
    while len (restline) > maxline:
        # find space in first maxline chars
        spacePos = string.rfind (restline [:maxline], ' ')
        if spacePos == -1:
            # find space in whole restline
            spacePos = string.find (restline, ' ', maxline)
        if spacePos == -1:
            # use whole restline
            spacePos = len (restline)
        result.append (restline [:spacePos])
        restline = restline [spacePos + 1:]
    if restline:
        result.append (restline)
    return result

def wordWrapLines (lines, maxline = 60):
    result = []
    for line in lines:
        result.extend (wordWrapLine (line, maxline))
    return string.join ([''] + result, '\n  ')

def sapdberr (errno):
    result = _errInfos.get (errno)
    if result is None and (errno > 0):
        result = _errInfos.get (-errno)
    if result is None:
        print 'no error info for message number', errno
    else:
        area, no, msg, explanation, userAction = result
        print area + ':', no, msg
        if explanation:
            print '\nExplanation:', wordWrapLines (explanation)
        if userAction:
            print '\nUser Action:', wordWrapLines (userAction)

def main (options, args):
    for arg in args:
        sapdberr (int (arg))

if __name__ == '__main__':
    main (None, sys.argv [1:])